@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <apt-pkg/init.h>
 #include <apt-pkg/algorithms.h>
+#include <apt-pkg/aptconfiguration.h>
 
 #include "apt.h"
 #include "apt-utils.h"
@@ -37,6 +38,9 @@
 #include <pk-backend.h>
 #include <pk-backend-spawn.h>
 
+#define PREUPGRADE_BINARY    "/usr/bin/do-release-upgrade"
+#define GDEBI_BINARY         "/usr/bin/gdebi"
+
 /* static bodges */
 static bool _cancel = false;
 static PkBackendSpawn *spawn;
@@ -126,12 +130,20 @@ pk_backend_get_groups (PkBackend *backend)
 PkBitfield
 pk_backend_get_filters (PkBackend *backend)
 {
-	return pk_bitfield_from_enums (
-		PK_FILTER_ENUM_GUI,
-		PK_FILTER_ENUM_INSTALLED,
-		PK_FILTER_ENUM_DEVELOPMENT,
-		PK_FILTER_ENUM_FREE,
-		-1);
+    PkBitfield filters;
+    filters = pk_bitfield_from_enums (
+        PK_FILTER_ENUM_GUI,
+        PK_FILTER_ENUM_INSTALLED,
+        PK_FILTER_ENUM_DEVELOPMENT,
+        PK_FILTER_ENUM_FREE,
+        -1);
+
+    // if we have multiArch support we add the native filter
+    if (APT::Configuration::getArchitectures(false).size() > 1) {
+        pk_bitfield_add(filters, PK_FILTER_ENUM_ARCH);
+    }
+
+    return filters;
 }
 
 /**
@@ -174,7 +186,6 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -192,7 +203,6 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 					       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
 					       pi);
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
@@ -205,7 +215,6 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 					       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
 					       "Couldn't find package");
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
@@ -220,7 +229,6 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 	m_apt->emit_packages(output, filters);
 
 	delete m_apt;
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -275,7 +283,6 @@ backend_get_files_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -287,7 +294,6 @@ backend_get_files_thread (PkBackend *backend)
 					       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
 					       pi);
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
@@ -298,15 +304,13 @@ backend_get_files_thread (PkBackend *backend)
 		{
 			pk_backend_error_code (backend, PK_ERROR_ENUM_PACKAGE_NOT_FOUND, "Couldn't find package");
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
-		emit_files (backend, pi);
+		m_apt->emitFiles(backend, pi);
 	}
 
 	delete m_apt;
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -325,7 +329,8 @@ backend_get_details_thread (PkBackend *backend)
 	gchar **package_ids;
 	gchar *pi;
 
-	bool updateDetail = pk_backend_get_bool (backend, "updateDetail");
+    PkRoleEnum role = pk_backend_get_role (backend);
+	bool updateDetail = role == PK_ROLE_ENUM_GET_UPDATE_DETAIL ? true : false;
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	if (package_ids == NULL) {
 		pk_backend_error_code (backend,
@@ -340,7 +345,6 @@ backend_get_details_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -350,41 +354,16 @@ backend_get_details_thread (PkBackend *backend)
         pkgInitSystem(*_config, _system);
     }
 
-	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	for (uint i = 0; i < g_strv_length(package_ids); i++) {
-		pi = package_ids[i];
-		if (pk_package_id_check(pi) == false) {
-			pk_backend_error_code (backend,
-					       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
-					       pi);
-			delete m_apt;
-			pk_backend_finished (backend);
-			return false;
-		}
+    pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
+    PkgList pkgs = m_apt->resolvePI(package_ids);
 
-		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-        bool found;
-		pkg_ver = m_apt->find_package_id(pi, found);
-		if (!found)
-		{
-			pk_backend_error_code (backend,
-					       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
-					       "couldn't find package");
-
-			delete m_apt;
-			pk_backend_finished (backend);
-			return false;
-		}
-
-		if (updateDetail) {
-			m_apt->emit_update_detail(pkg_ver.first, pkg_ver.second);
-		} else {
-			m_apt->emit_details(pkg_ver.first, pkg_ver.second);
-		}
-	}
+    if (updateDetail) {
+        m_apt->emitUpdateDetails(pkgs);
+    } else {
+        m_apt->emitDetails(pkgs);
+    }
 
 	delete m_apt;
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -394,8 +373,7 @@ backend_get_details_thread (PkBackend *backend)
 void
 pk_backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 {
-	pk_backend_set_bool (backend, "updateDetail", true);
-	pk_backend_thread_create (backend, backend_get_details_thread);
+    pk_backend_thread_create (backend, backend_get_details_thread);
 }
 
 /**
@@ -404,8 +382,7 @@ pk_backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 void
 pk_backend_get_details (PkBackend *backend, gchar **package_ids)
 {
-	pk_backend_set_bool (backend, "updateDetail", false);
-	pk_backend_thread_create (backend, backend_get_details_thread);
+    pk_backend_thread_create (backend, backend_get_details_thread);
 }
 
 static gboolean
@@ -422,7 +399,6 @@ backend_get_or_update_system_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -453,14 +429,13 @@ backend_get_or_update_system_thread (PkBackend *backend)
 		show_broken(backend, Cache, false);
 		g_debug ("Internal error, DistUpgrade broke stuff");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
 	bool res = true;
 	if (getUpdates) {
-		vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > update,
-									    kept;
+		PkgList update;
+		PkgList kept;
 
 		for(pkgCache::PkgIterator pkg=m_apt->packageCache->PkgBegin();
 		    !pkg.end();
@@ -469,12 +444,12 @@ backend_get_or_update_system_thread (PkBackend *backend)
 			if((*Cache)[pkg].Upgrade()    == true &&
 			(*Cache)[pkg].NewInstall() == false) {
 				update.push_back(
-					pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, m_apt->find_candidate_ver(pkg)));
+					PkgPair(pkg, m_apt->find_candidate_ver(pkg)));
 			} else if ((*Cache)[pkg].Upgradable() == true &&
 				pkg->CurrentVer != 0 &&
 				(*Cache)[pkg].Delete() == false) {
 				kept.push_back(
-					pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, m_apt->find_candidate_ver(pkg)));
+					PkgPair(pkg, m_apt->find_candidate_ver(pkg)));
 			}
 		}
 
@@ -485,7 +460,6 @@ backend_get_or_update_system_thread (PkBackend *backend)
 	}
 
 	delete m_apt;
-	pk_backend_finished (backend);
 	return res;
 }
 
@@ -535,7 +509,6 @@ backend_what_provides_thread (PkBackend *backend)
 			g_debug ("Failed to create apt cache");
 			g_strfreev (values);
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
@@ -597,9 +570,9 @@ backend_what_provides_thread (PkBackend *backend)
 				       PK_ERROR_ENUM_NOT_SUPPORTED,
 				       "Provides %s not supported",
 				       provides_text);
+        pk_backend_finished (backend);
 	}
 
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -633,7 +606,6 @@ pk_backend_download_packages_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -674,7 +646,6 @@ pk_backend_download_packages_thread (PkBackend *backend)
 					       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
 					       pi);
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
@@ -723,7 +694,6 @@ pk_backend_download_packages_thread (PkBackend *backend)
 	{
 		show_errors(backend, PK_ERROR_ENUM_PACKAGE_DOWNLOAD_FAILED);
 		delete m_apt;
-		pk_backend_finished (backend);
 		return _cancel;
 	}
 
@@ -731,7 +701,6 @@ pk_backend_download_packages_thread (PkBackend *backend)
 	pk_backend_files(backend, NULL, filelist.c_str());
 
 	delete m_apt;
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -757,7 +726,6 @@ pk_backend_refresh_cache_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -770,7 +738,6 @@ pk_backend_refresh_cache_thread (PkBackend *backend)
 		if (_error->PendingError() == true) {
 			pk_backend_error_code (backend, PK_ERROR_ENUM_CANNOT_GET_LOCK, "Unable to lock the list directory");
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 	// 	 return _error->Error(_("Unable to lock the list directory"));
 		}
@@ -789,7 +756,6 @@ pk_backend_refresh_cache_thread (PkBackend *backend)
 			show_errors(backend, PK_ERROR_ENUM_CANNOT_FETCH_SOURCES);
 		}
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -799,7 +765,6 @@ pk_backend_refresh_cache_thread (PkBackend *backend)
 		show_warnings(backend, PK_MESSAGE_ENUM_UNTRUSTED_PACKAGE);
 	}
 
-	pk_backend_finished (backend);
 	delete m_apt;
 	return true;
 }
@@ -813,7 +778,6 @@ pk_backend_refresh_cache (PkBackend *backend, gboolean force)
 	pk_backend_thread_create (backend, pk_backend_refresh_cache_thread);
 }
 
-
 static gboolean
 pk_backend_resolve_thread (PkBackend *backend)
 {
@@ -829,58 +793,15 @@ pk_backend_resolve_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
-	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	gchar *pi;
-	vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > output;
-	for (uint i = 0; i < g_strv_length(package_ids); i++) {
-		if (_cancel) {
-			break;
-		}
+    PkgList pkgs = m_apt->resolvePI(package_ids);
 
-		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-		pi = package_ids[i];
-		if (pk_package_id_check(pi) == false) {
-			pkg_ver.first = m_apt->packageCache->FindPkg(pi);
-			// Ignore packages that could not be found or that exist only due to dependencies.
-			if (pkg_ver.first.end() == true ||
-			    (pkg_ver.first.VersionList().end() && pkg_ver.first.ProvidesList().end()))
-			{
-				continue;
-			}
-
-			pkg_ver.second = m_apt->find_ver(pkg_ver.first);
-			// check to see if the provided package isn't virtual too
-			if (pkg_ver.second.end() == false)
-			{
-				output.push_back(pkg_ver);
-			}
-
-			pkg_ver.second = m_apt->find_candidate_ver(pkg_ver.first);
-			// check to see if the provided package isn't virtual too
-			if (pkg_ver.second.end() == false)
-			{
-				output.push_back(pkg_ver);
-			}
-		} else {
-            bool found;
-			pkg_ver = m_apt->find_package_id(pi, found);
-			// check to see if we found the package
-			if (found)
-			{
-				output.push_back(pkg_ver);
-			}
-		}
-	}
-	// It's faster to emmit the packages here rather than in the matching part
-	m_apt->emit_packages(output, filters);
+    // It's faster to emmit the packages here rather than in the matching part
+    m_apt->emit_packages(pkgs, filters);
 
 	delete m_apt;
-
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -911,7 +832,6 @@ pk_backend_search_files_thread (PkBackend *backend)
 		if (m_apt->init()) {
 			g_debug ("Failed to create apt cache");
 			delete m_apt;
-			pk_backend_finished (backend);
 			return false;
 		}
 
@@ -939,9 +859,10 @@ pk_backend_search_files_thread (PkBackend *backend)
 		m_apt->emit_packages(output, filters);
 
 		delete m_apt;
-	}
+    } else {
+        pk_backend_finished (backend);
+    }
 
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -983,7 +904,6 @@ backend_search_groups_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -1022,10 +942,8 @@ backend_search_groups_thread (PkBackend *backend)
 	// It's faster to emmit the packages here rather than in the matching part
 	m_apt->emit_packages(output, filters);
 
+    pk_backend_set_percentage (backend, 100);
 	delete m_apt;
-
-	pk_backend_set_percentage (backend, 100);
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -1067,7 +985,6 @@ backend_search_package_thread (PkBackend *backend)
 		g_debug ("Failed to create apt cache");
 		delete m_matcher;
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -1075,7 +992,6 @@ backend_search_package_thread (PkBackend *backend)
 	{
 		delete m_matcher;
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -1154,10 +1070,8 @@ backend_search_package_thread (PkBackend *backend)
 	m_apt->emit_packages(output, filters);
 
 	delete m_matcher;
+    pk_backend_set_percentage (backend, 100);
 	delete m_apt;
-
-	pk_backend_set_percentage (backend, 100);
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -1184,15 +1098,28 @@ pk_backend_search_details (PkBackend *backend, PkBitfield filters, gchar **value
 static gboolean
 backend_manage_packages_thread (PkBackend *backend)
 {
-	gchar **package_ids;
-	gchar *pi;
-	bool simulate;
-	bool remove;
-
-	package_ids = pk_backend_get_strv (backend, "package_ids");
-	simulate = pk_backend_get_bool (backend, "simulate");
-	remove = pk_backend_get_bool (backend, "remove");
+    bool simulate = false;
+    bool remove = false;
+    bool fileInstall = false;
+    gchar **full_paths = NULL;
 
+    PkRoleEnum role = pk_backend_get_role (backend);
+    if (role == PK_ROLE_ENUM_SIMULATE_INSTALL_FILES ||
+        role == PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES ||
+        role == PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES ||
+        role == PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES) {
+        simulate = true;
+    }
+    if (role == PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES ||
+        role == PK_ROLE_ENUM_REMOVE_PACKAGES) {
+        remove = true;
+    }
+    if (role == PK_ROLE_ENUM_SIMULATE_INSTALL_FILES ||
+        role == PK_ROLE_ENUM_INSTALL_FILES) {
+        full_paths = pk_backend_get_strv (backend, "full_paths");
+        fileInstall = true;
+    }
+cout << "FILE INSTALL: " << fileInstall << endl;
 	pk_backend_set_allow_cancel (backend, true);
 
 	aptcc *m_apt = new aptcc(backend, _cancel);
@@ -1200,89 +1127,88 @@ backend_manage_packages_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > pkgs;
-	for (uint i = 0; i < g_strv_length(package_ids); i++) {
-		if (_cancel) {
-			break;
-		}
+    PkgList installPkgs, removePkgs;
+    if (fileInstall) {
+        // GDebi can not install more than one package at time
+        if (g_strv_length(full_paths) > 1) {
+            pk_backend_error_code(backend,
+                                  PK_ERROR_ENUM_NOT_SUPPORTED,
+                                  "The backend can only proccess one file at time.");
+            delete m_apt;
+            return false;
+        }
 
-		pi = package_ids[i];
-		if (pk_package_id_check(pi) == false) {
-			pk_backend_error_code (backend,
-					       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
-					       pi);
-			delete m_apt;
-			pk_backend_finished (backend);
-			return false;
-		}
+        // get the list of packages to install
+        if (!m_apt->markDebFileForInstall(full_paths[0], installPkgs, removePkgs)) {
+            delete m_apt;
+            return false;
+        }
+        cout << "installPkgs.size: " << installPkgs.size() << endl;
+        cout << "removePkgs.size: " << removePkgs.size() << endl;
+    } else {
+        // Resolve the given packages
+        gchar **package_ids = pk_backend_get_strv(backend, "package_ids");
+        if (remove) {
+            removePkgs = m_apt->resolvePI(package_ids);
+        } else {
+            installPkgs = m_apt->resolvePI(package_ids);
+        }
 
-		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-        bool found;
-		pkg_ver = m_apt->find_package_id(pi, found);
-		// Ignore packages that could not be found or that exist only due to dependencies.
-		if (!found)
-		{
-			pk_backend_error_code (backend,
-					       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
-					       "couldn't find package");
+        if (removePkgs.size() == 0 && installPkgs.size() == 0) {
+            pk_backend_error_code(backend,
+                                  PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
+                                  "Could not find package(s)");
+            delete m_apt;
+            return false;
+        }
+    }
 
-			delete m_apt;
-			pk_backend_finished (backend);
-			return false;
-		} else {
-			pkgs.push_back(pkg_ver);
-		}
-	}
+    // Install/Update/Remove packages, or just simulate
+    if (!m_apt->runTransaction(installPkgs, removePkgs, simulate)) {
+        // Print transaction errors
+        cout << "runTransaction failed" << endl;
+        delete m_apt;
+        return false;
+    }
 
-	if (!m_apt->runTransaction(pkgs, simulate, remove)) {
-		// Print transaction errors
-		cout << "runTransaction failed" << endl;
-		delete m_apt;
-		pk_backend_finished (backend);
-		return false;
-	}
+    if (fileInstall) {
+        // File installation EXPERIMENTAL
+//         gchar *path;
+//
+//         for (uint i = 0; i < g_strv_length(full_paths); i++) {
+//             if (_cancel) {
+//                 break;
+//             }
+//
+//             path = full_paths[i];
+//             cout << "InstallFiles: " << m_apt->installDebFiles(path, simulate) << endl;
+//         }
+    }
 
 	delete m_apt;
-	pk_backend_finished (backend);
 	return true;
 }
 
-/**
- * pk_backend_install_packages:
- */
-void
-pk_backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
-{
-	pk_backend_set_bool(backend, "simulate", false);
-	pk_backend_set_bool(backend, "remove", false);
-	pk_backend_thread_create (backend, backend_manage_packages_thread);
-}
-
-/**
- * pk_backend_update_packages:
- */
-void
-pk_backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
-{
-	pk_backend_set_bool(backend, "simulate", false);
-	pk_backend_set_bool(backend, "remove", false);
-	pk_backend_thread_create (backend, backend_manage_packages_thread);
-}
-
 /**
  * pk_backend_simulate_install_packages:
  */
 void
 pk_backend_simulate_install_packages (PkBackend *backend, gchar **packages)
 {
-	pk_backend_set_bool(backend, "simulate", true);
-	pk_backend_set_bool(backend, "remove", false);
-	pk_backend_thread_create (backend, backend_manage_packages_thread);
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
+}
+
+/**
+ * pk_backend_install_packages:
+ */
+void
+pk_backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+{
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
 }
 
 /**
@@ -1291,20 +1217,34 @@ pk_backend_simulate_install_packages (PkBackend *backend, gchar **packages)
 void
 pk_backend_simulate_update_packages (PkBackend *backend, gchar **packages)
 {
-	pk_backend_set_bool(backend, "simulate", true);
-	pk_backend_set_bool(backend, "remove", false);
-	pk_backend_thread_create (backend, backend_manage_packages_thread);
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
 }
 
 /**
- * pk_backend_remove_packages:
+ * pk_backend_update_packages:
  */
 void
-pk_backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
+pk_backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
-	pk_backend_set_bool(backend, "simulate", false);
-	pk_backend_set_bool(backend, "remove", true);
-	pk_backend_thread_create (backend, backend_manage_packages_thread);
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
+}
+
+/**
+ * pk_backend_simulate_install_files:
+ */
+void
+pk_backend_simulate_install_files (PkBackend *backend, gchar **full_paths)
+{
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
+}
+
+/**
+ * pk_backend_install_files:
+ */
+void
+pk_backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
+{
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
 }
 
 /**
@@ -1313,9 +1253,16 @@ pk_backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean al
 void
 pk_backend_simulate_remove_packages (PkBackend *backend, gchar **packages, gboolean autoremove)
 {
-	pk_backend_set_bool(backend, "simulate", true);
-	pk_backend_set_bool(backend, "remove", true);
-	pk_backend_thread_create (backend, backend_manage_packages_thread);
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
+}
+
+/**
+ * pk_backend_remove_packages:
+ */
+void
+pk_backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
+{
+    pk_backend_thread_create (backend, backend_manage_packages_thread);
 }
 
 static gboolean
@@ -1454,7 +1401,6 @@ backend_get_packages_thread (PkBackend *backend)
 	if (m_apt->init()) {
 		g_debug ("Failed to create apt cache");
 		delete m_apt;
-		pk_backend_finished (backend);
 		return false;
 	}
 
@@ -1482,8 +1428,6 @@ backend_get_packages_thread (PkBackend *backend)
 	m_apt->emit_packages(output, filters);
 
 	delete m_apt;
-
-	pk_backend_finished (backend);
 	return true;
 }
 
@@ -1495,3 +1439,65 @@ pk_backend_get_packages (PkBackend *backend, PkBitfield filter)
 {
 	pk_backend_thread_create (backend, backend_get_packages_thread);
 }
+
+
+/**
+ * pk_backend_get_categories:
+ */
+/* TODO
+void
+pk_backend_get_categories (PkBackend *backend)
+{
+	pk_backend_thread_create (backend, pk_backend_get_categories_thread);
+}
+*/
+
+/**
+ * pk_backend_get_roles:
+ */
+PkBitfield
+pk_backend_get_roles (PkBackend *backend)
+{
+    PkBitfield roles;
+    roles = pk_bitfield_from_enums (
+        PK_ROLE_ENUM_CANCEL,
+        PK_ROLE_ENUM_GET_DEPENDS,
+        PK_ROLE_ENUM_GET_DETAILS,
+        PK_ROLE_ENUM_GET_FILES,
+        PK_ROLE_ENUM_GET_REQUIRES,
+        PK_ROLE_ENUM_GET_PACKAGES,
+        PK_ROLE_ENUM_WHAT_PROVIDES,
+        PK_ROLE_ENUM_GET_UPDATES,
+        PK_ROLE_ENUM_GET_UPDATE_DETAIL,
+        PK_ROLE_ENUM_INSTALL_PACKAGES,
+        PK_ROLE_ENUM_INSTALL_SIGNATURE,
+        PK_ROLE_ENUM_REFRESH_CACHE,
+        PK_ROLE_ENUM_REMOVE_PACKAGES,
+        PK_ROLE_ENUM_DOWNLOAD_PACKAGES,
+        PK_ROLE_ENUM_RESOLVE,
+        PK_ROLE_ENUM_SEARCH_DETAILS,
+        PK_ROLE_ENUM_SEARCH_FILE,
+        PK_ROLE_ENUM_SEARCH_GROUP,
+        PK_ROLE_ENUM_SEARCH_NAME,
+        PK_ROLE_ENUM_UPDATE_PACKAGES,
+        PK_ROLE_ENUM_UPDATE_SYSTEM,
+        PK_ROLE_ENUM_GET_REPO_LIST,
+        PK_ROLE_ENUM_REPO_ENABLE,
+        PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES,
+        PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,
+        PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,
+        -1);
+
+    // only add GetDistroUpgrades if the binary is present
+    if (g_file_test (PREUPGRADE_BINARY, G_FILE_TEST_EXISTS)) {
+        pk_bitfield_add(roles, PK_ROLE_ENUM_GET_DISTRO_UPGRADES);
+    }
+
+    // only add GetDistroUpgrades if the binary is present
+    if (g_file_test (GDEBI_BINARY, G_FILE_TEST_EXISTS)) {
+        pk_bitfield_add(roles, PK_ROLE_ENUM_SIMULATE_INSTALL_FILES);
+        pk_bitfield_add(roles, PK_ROLE_ENUM_INSTALL_FILES);
+    }
+
+    return roles;
+}
