@@ -22,6 +22,26 @@
 /** \file pkg_acqfile.h
  */
 
+class pkgAcqFileSane:public pkgAcquire::Item
+// This is frustrating: pkgAcqFile is **almost** good enough, but has some
+// hardcoded stuff that makes it not quite work.
+//
+//  Based heavily on that class, though.
+{
+  pkgAcquire::ItemDesc Desc;
+  string Md5Hash;
+  unsigned int Retries;
+
+public:
+  pkgAcqFileSane(pkgAcquire *Owner, string URI,
+         string Description, string ShortDesc, string filename);
+
+  void Failed(string Message, pkgAcquire::MethodConfig *Cnf);
+  string MD5Sum() {return Md5Hash;}
+  string DescURI() {return Desc.URI;}
+  virtual ~pkgAcqFileSane() {}
+};
+
 /** Like pkgAcqArchive, but uses generic File objects to download to
  *  the cwd (and copies from file:/ URLs).
  */
