@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 #
 # Copyright (C) 2007 Richard Hughes <richard@hughsie.com>
 #
@@ -9,11 +9,17 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-echo "no-percentage-updates" > /dev/stderr
-echo "status	query" > /dev/stderr
+echo -e "no-percentage-updates"
 sleep 1
-echo "package	1	glib2;2.14.0;i386;fedora	The GLib library"
+echo -e "percentage\t10"
+echo -e "status\tquery"
 sleep 1
-echo "package	1	gtk2;gtk2-2.11.6-6.fc8;i386;fedora	GTK+ Libraries for GIMP"
+echo -e "percentage\t30"
+echo -e "package\tavailable\tglib2;2.14.0;i386;fedora\tThe GLib library"
+sleep 1
+echo -e "percentage\t70"
+echo -e "package\tinstalled\tgtk2;gtk2-2.11.6-6.fc8;i386;fedora\tGTK+ Libraries for GIMP"
+sleep 1
+echo -e "percentage\t100"
 exit 0
 
