@@ -23,9 +23,12 @@
 #include <glib.h>
 #include <pk-backend.h>
 #include <pk-backend-spawn.h>
+#include <pk-shared.h>
 #include <unistd.h>
 #include <string>
 #include <set>
+#include <map>
+#include <list>
 #include <glib/gi18n.h>
 #include <sys/vfs.h>
 
@@ -60,12 +63,16 @@
 
 #include <zypp/sat/Solvable.h>
 
-#include <map>
-#include <list>
+#include "pk-backend-zypp-private.h"
 
 #include "zypp-utils.h"
 #include "zypp-events.h"
 
+using namespace std;
+using namespace zypp;
+
+PkBackendZYppPrivate *priv = 0L;
+
 enum PkgSearchType {
 	SEARCH_TYPE_NAME = 0,
 	SEARCH_TYPE_DETAILS = 1,
@@ -73,17 +80,6 @@ enum PkgSearchType {
 	SEARCH_TYPE_RESOLVE = 3
 };
 
-using namespace std;
-using namespace zypp;
-
-/**
- * A map to keep track of the EventDirector objects for
- * each zypp backend that is created.
- */
-static map<PkBackend *, EventDirector *> _eventDirectors;
-
-map<PkBackend *, vector<string> *> _signatures;
-
 // helper function to restore the pool status
 // after doing operations on it
 class PoolStatusSaver : private base::NonCopyable
@@ -128,14 +124,15 @@ pk_backend_get_author (PkBackend *backend)
 void
 pk_backend_initialize (PkBackend *backend)
 {
+	/* create private area */
+	priv = new PkBackendZYppPrivate;
 	zypp_logging ();
-//	disabled get_zypp() - too slow for a dbus timeout after zypper clean -a
 	g_debug ("zypp_backend_initialize");
 	EventDirector *eventDirector = new EventDirector (backend);
-	_eventDirectors [backend] = eventDirector;
-	vector<string> *signature = new vector<string> ();
-	_signatures [backend] = signature;
-	_updating_self = FALSE;
+	priv->eventDirectors[backend] = eventDirector;
+	vector<string> *signature = new vector<string>();
+	priv->signatures[backend] = signature;
+	//_updating_self = FALSE;
 }
 
 /**
@@ -147,13 +144,12 @@ pk_backend_destroy (PkBackend *backend)
 {
 	g_debug ("zypp_backend_destroy");
 
-	delete (_eventDirectors [backend]);
-	_eventDirectors.erase (backend);
-
-	delete (_signatures[backend]);
-	_signatures.erase (backend);
-
+	delete priv->eventDirectors [backend];
+	priv->eventDirectors.erase(backend);
+	delete priv->signatures[backend];
+	priv->signatures.erase(backend);
 	g_free (_repoName);
+	delete priv;
 }
 
 /**
@@ -185,13 +181,12 @@ backend_get_requires_thread (PkBackend *backend)
 	//pk_backend_set_percentage (backend, 0);
 
 	PoolStatusSaver saver;
+	ResPool pool = zypp_build_pool (backend, true);
 	for (uint i = 0; package_ids[i]; i++) {
 		sat::Solvable solvable = zypp_get_package_by_id (backend, package_ids[i]);
 		PoolItem package;
 
 		if (solvable.isSystem ()) {
-			ResPool pool = zypp_build_pool (backend, true);
-
 			gboolean found = FALSE;
 			gchar **id_parts = pk_package_id_split (package_ids[i]);
 
@@ -575,7 +570,7 @@ backend_get_details_thread (PkBackend *backend)
 						    package.lookupStrAttribute (sat::SolvAttr::license).c_str (),
 						    group,
 						    package.lookupStrAttribute (sat::SolvAttr::description).c_str (),
-						    "TODO", // pkg->url ().c_str (),
+						    package.lookupStrAttribute (sat::SolvAttr::url).c_str (),
 						    size * 1024);
 			}
 
@@ -1201,7 +1196,7 @@ backend_install_signature_thread (PkBackend *backend)
 	pk_backend_set_status (backend, PK_STATUS_ENUM_SIG_CHECK);
 	const gchar *key_id = pk_backend_get_string (backend, "key_id");
 	const gchar *package_id = pk_backend_get_string (backend, "package_id");
-	_signatures[backend]->push_back ((string)(key_id));
+	priv->signatures[backend]->push_back ((string)(key_id));
 
 	pk_backend_finished (backend);
 	return TRUE;
@@ -2179,13 +2174,13 @@ pk_backend_transaction_start (PkBackend *backend)
 	gchar *pac;
 
 	locale = pk_backend_get_locale(backend);
-	if (!egg_strzero (locale)) {
+	if (!pk_strzero (locale)) {
 		setlocale(LC_ALL, locale);
 	}
 
 	/* http_proxy */
 	proxy_http = pk_backend_get_proxy_http (backend);
-	if (!egg_strzero (proxy_http)) {
+	if (!pk_strzero (proxy_http)) {
 		uri = pk_backend_spawn_convert_uri (proxy_http);
 		g_setenv ("http_proxy", uri, TRUE);
 		g_free (uri);
@@ -2193,7 +2188,7 @@ pk_backend_transaction_start (PkBackend *backend)
 
 	/* https_proxy */
 	proxy_https = pk_backend_get_proxy_https (backend);
-	if (!egg_strzero (proxy_https)) {
+	if (!pk_strzero (proxy_https)) {
 		uri = pk_backend_spawn_convert_uri (proxy_https);
 		g_setenv ("https_proxy", uri, TRUE);
 		g_free (uri);
@@ -2201,7 +2196,7 @@ pk_backend_transaction_start (PkBackend *backend)
 
 	/* ftp_proxy */
 	proxy_ftp = pk_backend_get_proxy_ftp (backend);
-	if (!egg_strzero (proxy_ftp)) {
+	if (!pk_strzero (proxy_ftp)) {
 		uri = pk_backend_spawn_convert_uri (proxy_ftp);
 		g_setenv ("ftp_proxy", uri, TRUE);
 		g_free (uri);
@@ -2209,7 +2204,7 @@ pk_backend_transaction_start (PkBackend *backend)
 
 	/* socks_proxy */
 	proxy_socks = pk_backend_get_proxy_socks (backend);
-	if (!egg_strzero (proxy_socks)) {
+	if (!pk_strzero (proxy_socks)) {
 		uri = pk_backend_spawn_convert_uri (proxy_socks);
 		g_setenv ("socks_proxy", uri, TRUE);
 		g_free (uri);
@@ -2217,13 +2212,13 @@ pk_backend_transaction_start (PkBackend *backend)
 
 	/* no_proxy */
 	no_proxy = pk_backend_get_no_proxy (backend);
-	if (!egg_strzero (no_proxy)) {
+	if (!pk_strzero (no_proxy)) {
 		g_setenv ("no_proxy", no_proxy, TRUE);
 	}
 
 	/* pac */
 	pac = pk_backend_get_pac (backend);
-	if (!egg_strzero (pac)) {
+	if (!pk_strzero (pac)) {
 		uri = pk_backend_spawn_convert_uri (pac);
 		g_setenv ("pac", uri, TRUE);
 		g_free (uri);
