@@ -30,6 +30,7 @@
 
 #include <string.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 
 #include <packagekit-glib2/pk-common.h>
 #include <packagekit-glib2/pk-enum.h>
@@ -45,6 +46,7 @@ static const PkEnumMatch enum_exit[] = {
 	{PK_EXIT_ENUM_KILLED,			"killed"},
 	{PK_EXIT_ENUM_NEED_UNTRUSTED,		"need-untrusted"},
 	{PK_EXIT_ENUM_CANCELLED_PRIORITY,	"cancelled-priority"},
+	{PK_EXIT_ENUM_SKIP_TRANSACTION,		"skip-transaction"},
 	{0, NULL}
 };
 
@@ -126,6 +128,8 @@ static const PkEnumMatch enum_role[] = {
 	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,		"simulate-remove-packages"},
 	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,		"simulate-update-packages"},
 	{PK_ROLE_ENUM_UPGRADE_SYSTEM,			"upgrade-system"},
+	{PK_ROLE_ENUM_REPAIR_SYSTEM,			"repair-system"},
+	{PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM,		"simulate-repair-system"},
 	{0, NULL}
 };
 
@@ -360,6 +364,8 @@ static const PkEnumMatch enum_provides[] = {
 	{PK_PROVIDES_ENUM_FONT,			"font"},
 	{PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER,	"postscript-driver"},
 	{PK_PROVIDES_ENUM_PLASMA_SERVICE,	"plasma-service"},
+	{PK_PROVIDES_ENUM_SHARED_LIB,		"shared-library"},
+	{PK_PROVIDES_ENUM_PYTHON,		"python-module"},
 	{0, NULL}
 };
 
@@ -373,203 +379,6 @@ static const PkEnumMatch enum_network[] = {
 	{0, NULL}
 };
 
-/* DO NOT ADD ENTRIES MANUALLY... Use pk-refresh-licenses in tools */
-static const PkEnumMatch enum_free_licenses[] = {
-	{PK_LICENSE_ENUM_UNKNOWN,		"unknown"},	/* fall though value */
-	{PK_LICENSE_ENUM_AAL,			"AAL"},
-	{PK_LICENSE_ENUM_ADOBE,			"Adobe"},
-	{PK_LICENSE_ENUM_ADSL,			"ADSL"},
-	{PK_LICENSE_ENUM_AFL,			"AFL"},
-	{PK_LICENSE_ENUM_AGPLV1,		"AGPLv1"},
-	{PK_LICENSE_ENUM_AMDPLPA,		"AMDPLPA"},
-	{PK_LICENSE_ENUM_AML,			"AML"},
-	{PK_LICENSE_ENUM_AMPAS_BSD,		"AMPAS BSD"},
-	{PK_LICENSE_ENUM_APSL_2_DOT_0,		"APSL 2.0"},
-	{PK_LICENSE_ENUM_ARL,			"ARL"},
-	{PK_LICENSE_ENUM_ARPHIC,		"Arphic"},
-	{PK_LICENSE_ENUM_ARTISTIC_2_DOT_0,	"Artistic 2.0"},
-	{PK_LICENSE_ENUM_ARTISTIC_CLARIFIED,	"Artistic clarified"},
-	{PK_LICENSE_ENUM_ASL_1_DOT_0,		"ASL 1.0"},
-	{PK_LICENSE_ENUM_ASL_1_DOT_1,		"ASL 1.1"},
-	{PK_LICENSE_ENUM_ASL_2_DOT_0,		"ASL 2.0"},
-	{PK_LICENSE_ENUM_BAEKMUK,		"Baekmuk"},
-	{PK_LICENSE_ENUM_BEOPEN,		"BeOpen"},
-	{PK_LICENSE_ENUM_BITTORRENT,		"BitTorrent"},
-	{PK_LICENSE_ENUM_BOOST,			"Boost"},
-	{PK_LICENSE_ENUM_BSD,			"BSD"},
-	{PK_LICENSE_ENUM_BSD_PROTECTION,	"BSD Protection"},
-	{PK_LICENSE_ENUM_BSD_WITH_ADVERTISING,	"BSD with advertising"},
-	{PK_LICENSE_ENUM_CATOSL,		"CATOSL"},
-	{PK_LICENSE_ENUM_CC0,			"CC0"},
-	{PK_LICENSE_ENUM_CC_BY,			"CC-BY"},
-	{PK_LICENSE_ENUM_CC_BY_SA,		"CC-BY-SA"},
-	{PK_LICENSE_ENUM_CDDL,			"CDDL"},
-	{PK_LICENSE_ENUM_CDL,			"CDL"},
-	{PK_LICENSE_ENUM_CECILL,		"CeCILL"},
-	{PK_LICENSE_ENUM_CECILL_B,		"CeCILL-B"},
-	{PK_LICENSE_ENUM_CECILL_C,		"CeCILL-C"},
-	{PK_LICENSE_ENUM_CNRI,			"CNRI"},
-	{PK_LICENSE_ENUM_CONDOR,		"Condor"},
-	{PK_LICENSE_ENUM_COPYRIGHT_ONLY,	"Copyright only"},
-	{PK_LICENSE_ENUM_CPAL,			"CPAL"},
-	{PK_LICENSE_ENUM_CPL,			"CPL"},
-	{PK_LICENSE_ENUM_CRYSTAL_STACKER,	"Crystal Stacker"},
-	{PK_LICENSE_ENUM_DOC,			"DOC"},
-	{PK_LICENSE_ENUM_DSL,			"DSL"},
-	{PK_LICENSE_ENUM_DVIPDFM,		"dvipdfm"},
-	{PK_LICENSE_ENUM_ECL_1_DOT_0,		"ECL 1.0"},
-	{PK_LICENSE_ENUM_ECL_2_DOT_0,		"ECL 2.0"},
-	{PK_LICENSE_ENUM_ECOS,			"eCos"},
-	{PK_LICENSE_ENUM_EFL_2_DOT_0,		"EFL 2.0"},
-	{PK_LICENSE_ENUM_ENTESSA,		"Entessa"},
-	{PK_LICENSE_ENUM_EPL,			"EPL"},
-	{PK_LICENSE_ENUM_ERPL,			"ERPL"},
-	{PK_LICENSE_ENUM_EUPL_1_DOT_1,		"EUPL 1.1"},
-	{PK_LICENSE_ENUM_EUROSYM,		"Eurosym"},
-	{PK_LICENSE_ENUM_EU_DATAGRID,		"EU Datagrid"},
-	{PK_LICENSE_ENUM_FAIR,			"Fair"},
-	{PK_LICENSE_ENUM_FBSDDL,		"FBSDDL"},
-	{PK_LICENSE_ENUM_FREE_ART,		"Free Art"},
-	{PK_LICENSE_ENUM_FTL,			"FTL"},
-	{PK_LICENSE_ENUM_GEOGRATIS,		"GeoGratis"},
-	{PK_LICENSE_ENUM_GFDL,			"GFDL"},
-	{PK_LICENSE_ENUM_GIFTWARE,		"Giftware"},
-	{PK_LICENSE_ENUM_GL2PS,			"GL2PS"},
-	{PK_LICENSE_ENUM_GLIDE,			"Glide"},
-	{PK_LICENSE_ENUM_GNUPLOT,		"gnuplot"},
-	{PK_LICENSE_ENUM_GPLV1,			"GPLv1"},
-	{PK_LICENSE_ENUM_GPLV2,			"GPLv2"},
-	{PK_LICENSE_ENUM_GPLV2_OR_ARTISTIC,	"GPLv2 or Artistic"},
-	{PK_LICENSE_ENUM_GPLV2_PLUS,		"GPLv2+"},
-	{PK_LICENSE_ENUM_GPLV2_PLUS_OR_ARTISTIC, "GPLv2+ or Artistic"},
-	{PK_LICENSE_ENUM_GPLV2_PLUS_WITH_EXCEPTIONS, "GPLv2+ with exceptions"},
-	{PK_LICENSE_ENUM_GPLV2_WITH_EXCEPTIONS,	"GPLv2 with exceptions"},
-	{PK_LICENSE_ENUM_GPLV3,			"GPLv3"},
-	{PK_LICENSE_ENUM_GPLV3_PLUS,		"GPLv3+"},
-	{PK_LICENSE_ENUM_GPLV3_PLUS_WITH_EXCEPTIONS, "GPLv3+ with exceptions"},
-	{PK_LICENSE_ENUM_GPLV3_WITH_EXCEPTIONS,	"GPLv3 with exceptions"},
-	{PK_LICENSE_ENUM_GPL_PLUS,		"GPL+"},
-	{PK_LICENSE_ENUM_GPL_PLUS_OR_ARTISTIC,	"GPL+ or Artistic"},
-	{PK_LICENSE_ENUM_GPL_PLUS_WITH_EXCEPTIONS, "GPL+ with exceptions"},
-	{PK_LICENSE_ENUM_IBM,			"IBM"},
-	{PK_LICENSE_ENUM_IEEE,			"IEEE"},
-	{PK_LICENSE_ENUM_IJG,			"IJG"},
-	{PK_LICENSE_ENUM_IMAGEMAGICK,		"ImageMagick"},
-	{PK_LICENSE_ENUM_IMATIX,		"iMatix"},
-	{PK_LICENSE_ENUM_IMLIB2,		"Imlib2"},
-	{PK_LICENSE_ENUM_INTEL_ACPI,		"Intel ACPI"},
-	{PK_LICENSE_ENUM_INTERBASE,		"Interbase"},
-	{PK_LICENSE_ENUM_IPA,			"IPA"},
-	{PK_LICENSE_ENUM_ISC,			"ISC"},
-	{PK_LICENSE_ENUM_JABBER,		"Jabber"},
-	{PK_LICENSE_ENUM_JASPER,		"JasPer"},
-	{PK_LICENSE_ENUM_JPYTHON,		"JPython"},
-	{PK_LICENSE_ENUM_KNUTH,			"Knuth"},
-	{PK_LICENSE_ENUM_LBNL_BSD,		"LBNL BSD"},
-	{PK_LICENSE_ENUM_LDPL,			"LDPL"},
-	{PK_LICENSE_ENUM_LGPLV2,		"LGPLv2"},
-	{PK_LICENSE_ENUM_LGPLV2_PLUS,		"LGPLv2+"},
-	{PK_LICENSE_ENUM_LGPLV2_PLUS_OR_ARTISTIC, "LGPLv2+ or Artistic"},
-	{PK_LICENSE_ENUM_LGPLV2_PLUS_WITH_EXCEPTIONS, "LGPLv2+ with exceptions"},
-	{PK_LICENSE_ENUM_LGPLV2_WITH_EXCEPTIONS, "LGPLv2 with exceptions"},
-	{PK_LICENSE_ENUM_LGPLV3,		"LGPLv3"},
-	{PK_LICENSE_ENUM_LGPLV3_PLUS,		"LGPLv3+"},
-	{PK_LICENSE_ENUM_LGPLV3_PLUS_WITH_EXCEPTIONS, "LGPLv3+ with exceptions"},
-	{PK_LICENSE_ENUM_LGPLV3_WITH_EXCEPTIONS, "LGPLv3 with exceptions"},
-	{PK_LICENSE_ENUM_LIBERATION,		"Liberation"},
-	{PK_LICENSE_ENUM_LIBTIFF,		"libtiff"},
-	{PK_LICENSE_ENUM_LLGPL,			"LLGPL"},
-	{PK_LICENSE_ENUM_LOGICA,		"Logica"},
-	{PK_LICENSE_ENUM_LPL,			"LPL"},
-	{PK_LICENSE_ENUM_LPPL,			"LPPL"},
-	{PK_LICENSE_ENUM_MECAB_IPADIC,		"mecab-ipadic"},
-	{PK_LICENSE_ENUM_MIROS,			"MirOS"},
-	{PK_LICENSE_ENUM_MIT,			"MIT"},
-	{PK_LICENSE_ENUM_MIT_WITH_ADVERTISING,	"MIT with advertising"},
-	{PK_LICENSE_ENUM_MOD_MACRO,		"mod_macro"},
-	{PK_LICENSE_ENUM_MOTOSOTO,		"Motosoto"},
-	{PK_LICENSE_ENUM_MPLUS,			"mplus"},
-	{PK_LICENSE_ENUM_MPLV1_DOT_0,		"MPLv1.0"},
-	{PK_LICENSE_ENUM_MPLV1_DOT_1,		"MPLv1.1"},
-	{PK_LICENSE_ENUM_MS_PL,			"MS-PL"},
-	{PK_LICENSE_ENUM_MS_RL,			"MS-RL"},
-	{PK_LICENSE_ENUM_NAUMEN,		"Naumen"},
-	{PK_LICENSE_ENUM_NCSA,			"NCSA"},
-	{PK_LICENSE_ENUM_NETCDF,		"NetCDF"},
-	{PK_LICENSE_ENUM_NETSCAPE,		"Netscape"},
-	{PK_LICENSE_ENUM_NEWMAT,		"Newmat"},
-	{PK_LICENSE_ENUM_NGPL,			"NGPL"},
-	{PK_LICENSE_ENUM_NOKIA,			"Nokia"},
-	{PK_LICENSE_ENUM_NOSL,			"NOSL"},
-	{PK_LICENSE_ENUM_NOWEB,			"Noweb"},
-	{PK_LICENSE_ENUM_OAL,			"OAL"},
-	{PK_LICENSE_ENUM_OFL,			"OFL"},
-	{PK_LICENSE_ENUM_OFSFDL,		"OFSFDL"},
-	{PK_LICENSE_ENUM_OML,			"OML"},
-	{PK_LICENSE_ENUM_OPENLDAP,		"OpenLDAP"},
-	{PK_LICENSE_ENUM_OPENPBS,		"OpenPBS"},
-	{PK_LICENSE_ENUM_OPENSSL,		"OpenSSL"},
-	{PK_LICENSE_ENUM_OREILLY,		"OReilly"},
-	{PK_LICENSE_ENUM_OSL_1_DOT_0,		"OSL 1.0"},
-	{PK_LICENSE_ENUM_OSL_1_DOT_1,		"OSL 1.1"},
-	{PK_LICENSE_ENUM_OSL_2_DOT_0,		"OSL 2.0"},
-	{PK_LICENSE_ENUM_OSL_2_DOT_1,		"OSL 2.1"},
-	{PK_LICENSE_ENUM_OSL_3_DOT_0,		"OSL 3.0"},
-	{PK_LICENSE_ENUM_PHORUM,		"Phorum"},
-	{PK_LICENSE_ENUM_PHP,			"PHP"},
-	{PK_LICENSE_ENUM_PLEXUS,		"Plexus"},
-	{PK_LICENSE_ENUM_POSTGRESQL,		"PostgreSQL"},
-	{PK_LICENSE_ENUM_PSUTILS,		"psutils"},
-	{PK_LICENSE_ENUM_PTFL,			"PTFL"},
-	{PK_LICENSE_ENUM_PUBLIC_DOMAIN,		"Public Domain"},
-	{PK_LICENSE_ENUM_PUBLIC_USE,		"Public Use"},
-	{PK_LICENSE_ENUM_PYTHON,		"Python"},
-	{PK_LICENSE_ENUM_QHULL,			"Qhull"},
-	{PK_LICENSE_ENUM_QPL,			"QPL"},
-	{PK_LICENSE_ENUM_RDISC,			"Rdisc"},
-	{PK_LICENSE_ENUM_RICEBSD,		"RiceBSD"},
-	{PK_LICENSE_ENUM_ROMIO,			"Romio"},
-	{PK_LICENSE_ENUM_RPSL,			"RPSL"},
-	{PK_LICENSE_ENUM_RUBY,			"Ruby"},
-	{PK_LICENSE_ENUM_SAXPATH,		"Saxpath"},
-	{PK_LICENSE_ENUM_SCEA,			"SCEA"},
-	{PK_LICENSE_ENUM_SCRIP,			"SCRIP"},
-	{PK_LICENSE_ENUM_SENDMAIL,		"Sendmail"},
-	{PK_LICENSE_ENUM_SISSL,			"SISSL"},
-	{PK_LICENSE_ENUM_SLEEPYCAT,		"Sleepycat"},
-	{PK_LICENSE_ENUM_SLIB,			"SLIB"},
-	{PK_LICENSE_ENUM_SNIA,			"SNIA"},
-	{PK_LICENSE_ENUM_SPL,			"SPL"},
-	{PK_LICENSE_ENUM_STIX,			"STIX"},
-	{PK_LICENSE_ENUM_TCL,			"TCL"},
-	{PK_LICENSE_ENUM_TEEWORLDS,		"Teeworlds"},
-	{PK_LICENSE_ENUM_TMATE,			"TMate"},
-	{PK_LICENSE_ENUM_TOSL,			"TOSL"},
-	{PK_LICENSE_ENUM_TPL,			"TPL"},
-	{PK_LICENSE_ENUM_UCD,			"UCD"},
-	{PK_LICENSE_ENUM_VIM,			"Vim"},
-	{PK_LICENSE_ENUM_VNLSL,			"VNLSL"},
-	{PK_LICENSE_ENUM_VOSTROM,		"VOSTROM"},
-	{PK_LICENSE_ENUM_VSL,			"VSL"},
-	{PK_LICENSE_ENUM_W3C,			"W3C"},
-	{PK_LICENSE_ENUM_WADALAB,		"Wadalab"},
-	{PK_LICENSE_ENUM_WEBMIN,		"Webmin"},
-	{PK_LICENSE_ENUM_WTFPL,			"WTFPL"},
-	{PK_LICENSE_ENUM_WXWIDGETS,		"wxWidgets"},
-	{PK_LICENSE_ENUM_XANO,			"XANO"},
-	{PK_LICENSE_ENUM_XEROX,			"Xerox"},
-	{PK_LICENSE_ENUM_XINETD,		"xinetd"},
-	{PK_LICENSE_ENUM_XSKAT,			"XSkat"},
-	{PK_LICENSE_ENUM_YPLV1_DOT_1,		"YPLv1.1"},
-	{PK_LICENSE_ENUM_ZEND,			"Zend"},
-	{PK_LICENSE_ENUM_ZLIB,			"zlib"},
-	{PK_LICENSE_ENUM_ZLIB_WITH_ACKNOWLEDGEMENT, "zlib with acknowledgement"},
-	{PK_LICENSE_ENUM_ZPLV1_DOT_0,		"ZPLv1.0"},
-	{PK_LICENSE_ENUM_ZPLV2_DOT_0,		"ZPLv2.0"},
-	{PK_LICENSE_ENUM_ZPLV2_DOT_1,		"ZPLv2.1"},
-	{0, NULL}
-};
-
 static const PkEnumMatch enum_media_type[] = {
 	{PK_MEDIA_TYPE_ENUM_UNKNOWN,		"unknown"},	/* fall though value */
 	{PK_MEDIA_TYPE_ENUM_CD,			"cd"},
@@ -1097,38 +906,6 @@ pk_filter_enum_to_string (PkFilterEnum filter)
 	return pk_enum_find_string (enum_filter, filter);
 }
 
-/**
- * pk_license_enum_from_string:
- * @license: Text describing the enumerated type
- *
- * Converts a text enumerated type to its unsigned integer representation
- *
- * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
- *
- * Since: 0.5.0
- **/
-PkLicenseEnum
-pk_license_enum_from_string (const gchar *license)
-{
-	return pk_enum_find_value (enum_free_licenses, license);
-}
-
-/**
- * pk_license_enum_to_string:
- * @license: The enumerated type value
- *
- * Converts a enumerated type to its text representation
- *
- * Return value: the enumerated constant value, e.g. "available"
- *
- * Since: 0.5.0
- **/
-const gchar *
-pk_license_enum_to_string (PkLicenseEnum license)
-{
-	return pk_enum_find_string (enum_free_licenses, license);
-}
-
 /**
  * pk_media_type_enum_from_string:
  * @media_type: Text describing the enumerated type
@@ -1224,3 +1001,321 @@ pk_upgrade_kind_enum_to_string (PkUpgradeKindEnum upgrade_kind)
 {
 	return pk_enum_find_string (enum_upgrade_kind, upgrade_kind);
 }
+
+/**
+ * pk_info_enum_to_localised_text:
+ * @info: The enumerated type value
+ * 
+ * Converts a enumerated type to its localized description
+ *
+ * Return Value: the translated text
+ *
+ * Since: 0.7.2
+ **/
+static const gchar *
+pk_info_enum_to_localised_text (PkInfoEnum info)
+{
+	const gchar *text = NULL;
+	switch (info) {
+	case PK_INFO_ENUM_LOW:
+		/* TRANSLATORS: The type of update */
+		text = _("Trivial");
+		break;
+	case PK_INFO_ENUM_NORMAL:
+		/* TRANSLATORS: The type of update */
+		text = dgettext("PackageKit", "Normal");
+		break;
+	case PK_INFO_ENUM_IMPORTANT:
+		/* TRANSLATORS: The type of update */
+		text = dgettext("PackageKit", "Important");
+		break;
+	case PK_INFO_ENUM_SECURITY:
+		/* TRANSLATORS: The type of update */
+		text = dgettext("PackageKit", "Security");
+		break;
+	case PK_INFO_ENUM_BUGFIX:
+		/* TRANSLATORS: The type of update */
+		text = dgettext("PackageKit", "Bug fix ");
+		break;
+	case PK_INFO_ENUM_ENHANCEMENT:
+		/* TRANSLATORS: The type of update */
+		text = dgettext("PackageKit", "Enhancement");
+		break;
+	case PK_INFO_ENUM_BLOCKED:
+		/* TRANSLATORS: The type of update */
+		text = dgettext("PackageKit", "Blocked");
+		break;
+	case PK_INFO_ENUM_INSTALLED:
+	case PK_INFO_ENUM_COLLECTION_INSTALLED:
+		/* TRANSLATORS: The state of a package */
+		text = dgettext("PackageKit", "Installed");
+		break;
+	case PK_INFO_ENUM_AVAILABLE:
+	case PK_INFO_ENUM_COLLECTION_AVAILABLE:
+		/* TRANSLATORS: The state of a package, i.e. not installed */
+		text = dgettext("PackageKit", "Available");
+		break;
+	default:
+		g_warning ("info unrecognised: %s", pk_info_enum_to_string (info));
+	}
+	return text;
+}
+
+/**
+ * pk_info_enum_to_localised_present:
+ * @info: The enumerated type value
+ * 
+ * Converts a enumerated type to its localized description
+ *
+ * Return Value: the translated text
+ *
+ * Since: 0.7.2
+ **/
+const gchar *
+pk_info_enum_to_localised_present (PkInfoEnum info)
+{
+	const gchar *text = NULL;
+	switch (info) {
+	case PK_INFO_ENUM_DOWNLOADING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Downloading");
+		break;
+	case PK_INFO_ENUM_UPDATING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Updating");
+		break;
+	case PK_INFO_ENUM_INSTALLING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Installing");
+		break;
+	case PK_INFO_ENUM_REMOVING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Removing");
+		break;
+	case PK_INFO_ENUM_CLEANUP:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Cleaning up");
+		break;
+	case PK_INFO_ENUM_OBSOLETING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Obsoleting");
+		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = dgettext("PackageKit", "Reinstalling");
+		break;
+	default:
+		text = pk_info_enum_to_localised_text (info);
+	}
+	return text;
+}
+
+/**
+ * pk_info_enum_to_localised_past:
+ * @info: The enumerated type value
+ * 
+ * Converts a enumerated type to its localized description
+ *
+ * Return Value: the translated text
+ *
+ * Since: 0.7.2
+ **/
+const gchar *
+pk_info_enum_to_localised_past (PkInfoEnum info)
+{
+	const gchar *text = NULL;
+	switch (info) {
+	case PK_INFO_ENUM_DOWNLOADING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Downloaded");
+		break;
+	case PK_INFO_ENUM_UPDATING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Updated");
+		break;
+	case PK_INFO_ENUM_INSTALLING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Installed");
+		break;
+	case PK_INFO_ENUM_REMOVING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Removed");
+		break;
+	case PK_INFO_ENUM_CLEANUP:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Cleaned up");
+		break;
+	case PK_INFO_ENUM_OBSOLETING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Obsoleted");
+		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = dgettext("PackageKit", "Reinstalled");
+		break;
+	default:
+		text = pk_info_enum_to_localised_text (info);
+	}
+	return text;
+}
+
+/**
+ * pk_role_enum_to_localised_present:
+ * @role: The enumerated type value
+ * 
+ * Converts a enumerated type to its localized description
+ *
+ * Return Value: the translated text
+ *
+ * Since: 0.7.2
+ **/
+const gchar *
+pk_role_enum_to_localised_present (PkRoleEnum role)
+{
+	const gchar *text = NULL;
+	switch (role) {
+	case PK_ROLE_ENUM_UNKNOWN:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Unknown role type");
+		break;
+	case PK_ROLE_ENUM_GET_DEPENDS:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting dependencies");
+		break;
+	case PK_ROLE_ENUM_GET_UPDATE_DETAIL:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting update details");
+		break;
+	case PK_ROLE_ENUM_GET_DETAILS:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting details");
+		break;
+	case PK_ROLE_ENUM_GET_REQUIRES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting requires");
+		break;
+	case PK_ROLE_ENUM_GET_UPDATES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting updates");
+		break;
+	case PK_ROLE_ENUM_SEARCH_DETAILS:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Searching by details");
+		break;
+	case PK_ROLE_ENUM_SEARCH_FILE:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Searching by file");
+		break;
+	case PK_ROLE_ENUM_SEARCH_GROUP:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Searching groups");
+		break;
+	case PK_ROLE_ENUM_SEARCH_NAME:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Searching by name");
+		break;
+	case PK_ROLE_ENUM_REMOVE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Removing");
+		break;
+	case PK_ROLE_ENUM_INSTALL_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Installing");
+		break;
+	case PK_ROLE_ENUM_INSTALL_FILES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Installing files");
+		break;
+	case PK_ROLE_ENUM_REFRESH_CACHE:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Refreshing cache");
+		break;
+	case PK_ROLE_ENUM_UPDATE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Updating packages");
+		break;
+	case PK_ROLE_ENUM_UPDATE_SYSTEM:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Updating system");
+		break;
+	case PK_ROLE_ENUM_CANCEL:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Canceling");
+		break;
+	case PK_ROLE_ENUM_ROLLBACK:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Rolling back");
+		break;
+	case PK_ROLE_ENUM_GET_REPO_LIST:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting repositories");
+		break;
+	case PK_ROLE_ENUM_REPO_ENABLE:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Enabling repository");
+		break;
+	case PK_ROLE_ENUM_REPO_SET_DATA:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Setting data");
+		break;
+	case PK_ROLE_ENUM_RESOLVE:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Resolving");
+		break;
+	case PK_ROLE_ENUM_GET_FILES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting file list");
+		break;
+	case PK_ROLE_ENUM_WHAT_PROVIDES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting provides");
+		break;
+	case PK_ROLE_ENUM_INSTALL_SIGNATURE:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Installing signature");
+		break;
+	case PK_ROLE_ENUM_GET_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting packages");
+		break;
+	case PK_ROLE_ENUM_ACCEPT_EULA:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Accepting EULA");
+		break;
+	case PK_ROLE_ENUM_DOWNLOAD_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Downloading packages");
+		break;
+	case PK_ROLE_ENUM_GET_DISTRO_UPGRADES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting upgrades");
+		break;
+	case PK_ROLE_ENUM_GET_CATEGORIES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting categories");
+		break;
+	case PK_ROLE_ENUM_GET_OLD_TRANSACTIONS:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Getting transactions");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Simulating install");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Simulating install");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Simulating remove");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = dgettext("PackageKit", "Simulating update");
+		break;
+	default:
+		g_warning ("role unrecognised: %s", pk_role_enum_to_string (role));
+	}
+	return text;
+}
