@@ -30,42 +30,6 @@
 
 G_BEGIN_DECLS
 
-/* These are compatibility enums so we can break API in the future */
-#define pk_sig_type_enum_from_text		pk_sig_type_enum_from_string
-#define pk_sig_type_enum_to_text		pk_sig_type_enum_to_string
-#define pk_distro_upgrade_enum_from_text	pk_distro_upgrade_enum_from_string
-#define pk_distro_upgrade_enum_to_text		pk_distro_upgrade_enum_to_string
-#define pk_provides_enum_from_text		pk_provides_enum_from_string
-#define pk_provides_enum_to_text		pk_provides_enum_to_string
-#define pk_info_enum_from_text			pk_info_enum_from_string
-#define pk_info_enum_to_text			pk_info_enum_to_string
-#define pk_exit_enum_from_text			pk_exit_enum_from_string
-#define pk_exit_enum_to_text			pk_exit_enum_to_string
-#define pk_network_enum_from_text		pk_network_enum_from_string
-#define pk_network_enum_to_text			pk_network_enum_to_string
-#define pk_status_enum_from_text		pk_status_enum_from_string
-#define pk_status_enum_to_text			pk_status_enum_to_string
-#define pk_role_enum_from_text			pk_role_enum_from_string
-#define pk_role_enum_to_text			pk_role_enum_to_string
-#define pk_error_enum_from_text			pk_error_enum_from_string
-#define pk_error_enum_to_text			pk_error_enum_to_string
-#define pk_restart_enum_from_text		pk_restart_enum_from_string
-#define pk_restart_enum_to_text			pk_restart_enum_to_string
-#define pk_message_enum_from_text		pk_message_enum_from_string
-#define pk_message_enum_to_text			pk_message_enum_to_string
-#define pk_group_enum_from_text			pk_group_enum_from_string
-#define pk_group_enum_to_text			pk_group_enum_to_string
-#define pk_update_state_enum_from_text		pk_update_state_enum_from_string
-#define pk_update_state_enum_to_text		pk_update_state_enum_to_string
-#define pk_filter_enum_from_text		pk_filter_enum_from_string
-#define pk_filter_enum_to_text			pk_filter_enum_to_string
-#define pk_license_enum_from_text		pk_license_enum_from_string
-#define pk_license_enum_to_text			pk_license_enum_to_string
-#define pk_media_type_enum_from_text		pk_media_type_enum_from_string
-#define pk_media_type_enum_to_text		pk_media_type_enum_to_string
-#define pk_authorize_type_enum_from_text	pk_authorize_type_enum_from_string
-#define pk_authorize_type_enum_to_text		pk_authorize_type_enum_to_string
-
 /**
  * PkEnumMatch:
  *
@@ -121,6 +85,8 @@ typedef enum {
 	PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,
 	PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,
 	PK_ROLE_ENUM_UPGRADE_SYSTEM,			/* Since: 0.6.11 */
+	PK_ROLE_ENUM_REPAIR_SYSTEM,			/* Since: 0.7.2 */
+	PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM,		/* Since: 0.7.2 */
 	PK_ROLE_ENUM_LAST
 } PkRoleEnum;
 
@@ -201,6 +167,7 @@ typedef enum {
 	PK_EXIT_ENUM_MEDIA_CHANGE_REQUIRED,
 	PK_EXIT_ENUM_NEED_UNTRUSTED,
 	PK_EXIT_ENUM_CANCELLED_PRIORITY,
+	PK_EXIT_ENUM_SKIP_TRANSACTION,
 	PK_EXIT_ENUM_LAST
 } PkExitEnum;
 
@@ -487,7 +454,7 @@ typedef enum {
 /**
  * PkProvidesEnum:
  *
- * The signature type type
+ * Some component types packages can provide
  **/
 typedef enum {
 	PK_PROVIDES_ENUM_UNKNOWN,
@@ -499,205 +466,11 @@ typedef enum {
 	PK_PROVIDES_ENUM_HARDWARE_DRIVER,
 	PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER,
 	PK_PROVIDES_ENUM_PLASMA_SERVICE,
+	PK_PROVIDES_ENUM_SHARED_LIB,
+	PK_PROVIDES_ENUM_PYTHON,
 	PK_PROVIDES_ENUM_LAST
 } PkProvidesEnum;
 
-typedef enum {
-	PK_LICENSE_ENUM_UNKNOWN,
-	PK_LICENSE_ENUM_AAL,
-	PK_LICENSE_ENUM_ADOBE,
-	PK_LICENSE_ENUM_ADSL,
-	PK_LICENSE_ENUM_AFL,
-	PK_LICENSE_ENUM_AGPLV1,
-	PK_LICENSE_ENUM_AMDPLPA,
-	PK_LICENSE_ENUM_AML,
-	PK_LICENSE_ENUM_AMPAS_BSD,
-	PK_LICENSE_ENUM_APSL_2_DOT_0,
-	PK_LICENSE_ENUM_ARL,
-	PK_LICENSE_ENUM_ARPHIC,
-	PK_LICENSE_ENUM_ARTISTIC_2_DOT_0,
-	PK_LICENSE_ENUM_ARTISTIC_CLARIFIED,
-	PK_LICENSE_ENUM_ASL_1_DOT_0,
-	PK_LICENSE_ENUM_ASL_1_DOT_1,
-	PK_LICENSE_ENUM_ASL_2_DOT_0,
-	PK_LICENSE_ENUM_BAEKMUK,
-	PK_LICENSE_ENUM_BEOPEN,
-	PK_LICENSE_ENUM_BITTORRENT,
-	PK_LICENSE_ENUM_BOOST,
-	PK_LICENSE_ENUM_BSD,
-	PK_LICENSE_ENUM_BSD_PROTECTION,
-	PK_LICENSE_ENUM_BSD_WITH_ADVERTISING,
-	PK_LICENSE_ENUM_CATOSL,
-	PK_LICENSE_ENUM_CC0,
-	PK_LICENSE_ENUM_CC_BY,
-	PK_LICENSE_ENUM_CC_BY_SA,
-	PK_LICENSE_ENUM_CDDL,
-	PK_LICENSE_ENUM_CDL,
-	PK_LICENSE_ENUM_CECILL,
-	PK_LICENSE_ENUM_CECILL_B,
-	PK_LICENSE_ENUM_CECILL_C,
-	PK_LICENSE_ENUM_CNRI,
-	PK_LICENSE_ENUM_CONDOR,
-	PK_LICENSE_ENUM_COPYRIGHT_ONLY,
-	PK_LICENSE_ENUM_CPAL,
-	PK_LICENSE_ENUM_CPL,
-	PK_LICENSE_ENUM_CRYSTAL_STACKER,
-	PK_LICENSE_ENUM_DOC,
-	PK_LICENSE_ENUM_DSL,
-	PK_LICENSE_ENUM_DVIPDFM,
-	PK_LICENSE_ENUM_ECL_1_DOT_0,
-	PK_LICENSE_ENUM_ECL_2_DOT_0,
-	PK_LICENSE_ENUM_ECOS,
-	PK_LICENSE_ENUM_EFL_2_DOT_0,
-	PK_LICENSE_ENUM_ENTESSA,
-	PK_LICENSE_ENUM_EPL,
-	PK_LICENSE_ENUM_ERPL,
-	PK_LICENSE_ENUM_EUPL_1_DOT_1,
-	PK_LICENSE_ENUM_EUROSYM,
-	PK_LICENSE_ENUM_EU_DATAGRID,
-	PK_LICENSE_ENUM_FAIR,
-	PK_LICENSE_ENUM_FBSDDL,
-	PK_LICENSE_ENUM_FREE_ART,
-	PK_LICENSE_ENUM_FTL,
-	PK_LICENSE_ENUM_GEOGRATIS,
-	PK_LICENSE_ENUM_GFDL,
-	PK_LICENSE_ENUM_GIFTWARE,
-	PK_LICENSE_ENUM_GL2PS,
-	PK_LICENSE_ENUM_GLIDE,
-	PK_LICENSE_ENUM_GNUPLOT,
-	PK_LICENSE_ENUM_GPLV1,
-	PK_LICENSE_ENUM_GPLV2,
-	PK_LICENSE_ENUM_GPLV2_OR_ARTISTIC,
-	PK_LICENSE_ENUM_GPLV2_PLUS,
-	PK_LICENSE_ENUM_GPLV2_PLUS_OR_ARTISTIC,
-	PK_LICENSE_ENUM_GPLV2_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPLV2_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPLV3,
-	PK_LICENSE_ENUM_GPLV3_PLUS,
-	PK_LICENSE_ENUM_GPLV3_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPLV3_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPL_PLUS,
-	PK_LICENSE_ENUM_GPL_PLUS_OR_ARTISTIC,
-	PK_LICENSE_ENUM_GPL_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_IBM,
-	PK_LICENSE_ENUM_IEEE,
-	PK_LICENSE_ENUM_IJG,
-	PK_LICENSE_ENUM_IMAGEMAGICK,
-	PK_LICENSE_ENUM_IMATIX,
-	PK_LICENSE_ENUM_IMLIB2,
-	PK_LICENSE_ENUM_INTEL_ACPI,
-	PK_LICENSE_ENUM_INTERBASE,
-	PK_LICENSE_ENUM_IPA,
-	PK_LICENSE_ENUM_ISC,
-	PK_LICENSE_ENUM_JABBER,
-	PK_LICENSE_ENUM_JASPER,
-	PK_LICENSE_ENUM_JPYTHON,
-	PK_LICENSE_ENUM_KNUTH,
-	PK_LICENSE_ENUM_LBNL_BSD,
-	PK_LICENSE_ENUM_LDPL,
-	PK_LICENSE_ENUM_LGPLV2,
-	PK_LICENSE_ENUM_LGPLV2_PLUS,
-	PK_LICENSE_ENUM_LGPLV2_PLUS_OR_ARTISTIC,
-	PK_LICENSE_ENUM_LGPLV2_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_LGPLV2_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_LGPLV3,
-	PK_LICENSE_ENUM_LGPLV3_PLUS,
-	PK_LICENSE_ENUM_LGPLV3_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_LGPLV3_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_LIBERATION,
-	PK_LICENSE_ENUM_LIBTIFF,
-	PK_LICENSE_ENUM_LLGPL,
-	PK_LICENSE_ENUM_LOGICA,
-	PK_LICENSE_ENUM_LPL,
-	PK_LICENSE_ENUM_LPPL,
-	PK_LICENSE_ENUM_MECAB_IPADIC,
-	PK_LICENSE_ENUM_MIROS,
-	PK_LICENSE_ENUM_MIT,
-	PK_LICENSE_ENUM_MIT_WITH_ADVERTISING,
-	PK_LICENSE_ENUM_MOD_MACRO,
-	PK_LICENSE_ENUM_MOTOSOTO,
-	PK_LICENSE_ENUM_MPLUS,
-	PK_LICENSE_ENUM_MPLV1_DOT_0,
-	PK_LICENSE_ENUM_MPLV1_DOT_1,
-	PK_LICENSE_ENUM_MS_PL,
-	PK_LICENSE_ENUM_MS_RL,
-	PK_LICENSE_ENUM_NAUMEN,
-	PK_LICENSE_ENUM_NCSA,
-	PK_LICENSE_ENUM_NETCDF,
-	PK_LICENSE_ENUM_NETSCAPE,
-	PK_LICENSE_ENUM_NEWMAT,
-	PK_LICENSE_ENUM_NGPL,
-	PK_LICENSE_ENUM_NOKIA,
-	PK_LICENSE_ENUM_NOSL,
-	PK_LICENSE_ENUM_NOWEB,
-	PK_LICENSE_ENUM_OAL,
-	PK_LICENSE_ENUM_OFL,
-	PK_LICENSE_ENUM_OFSFDL,
-	PK_LICENSE_ENUM_OML,
-	PK_LICENSE_ENUM_OPENLDAP,
-	PK_LICENSE_ENUM_OPENPBS,
-	PK_LICENSE_ENUM_OPENSSL,
-	PK_LICENSE_ENUM_OREILLY,
-	PK_LICENSE_ENUM_OSL_1_DOT_0,
-	PK_LICENSE_ENUM_OSL_1_DOT_1,
-	PK_LICENSE_ENUM_OSL_2_DOT_0,
-	PK_LICENSE_ENUM_OSL_2_DOT_1,
-	PK_LICENSE_ENUM_OSL_3_DOT_0,
-	PK_LICENSE_ENUM_PHORUM,
-	PK_LICENSE_ENUM_PHP,
-	PK_LICENSE_ENUM_PLEXUS,
-	PK_LICENSE_ENUM_POSTGRESQL,
-	PK_LICENSE_ENUM_PSUTILS,
-	PK_LICENSE_ENUM_PTFL,
-	PK_LICENSE_ENUM_PUBLIC_DOMAIN,
-	PK_LICENSE_ENUM_PUBLIC_USE,
-	PK_LICENSE_ENUM_PYTHON,
-	PK_LICENSE_ENUM_QHULL,
-	PK_LICENSE_ENUM_QPL,
-	PK_LICENSE_ENUM_RDISC,
-	PK_LICENSE_ENUM_RICEBSD,
-	PK_LICENSE_ENUM_ROMIO,
-	PK_LICENSE_ENUM_RPSL,
-	PK_LICENSE_ENUM_RUBY,
-	PK_LICENSE_ENUM_SAXPATH,
-	PK_LICENSE_ENUM_SCEA,
-	PK_LICENSE_ENUM_SCRIP,
-	PK_LICENSE_ENUM_SENDMAIL,
-	PK_LICENSE_ENUM_SISSL,
-	PK_LICENSE_ENUM_SLEEPYCAT,
-	PK_LICENSE_ENUM_SLIB,
-	PK_LICENSE_ENUM_SNIA,
-	PK_LICENSE_ENUM_SPL,
-	PK_LICENSE_ENUM_STIX,
-	PK_LICENSE_ENUM_TCL,
-	PK_LICENSE_ENUM_TEEWORLDS,
-	PK_LICENSE_ENUM_TMATE,
-	PK_LICENSE_ENUM_TOSL,
-	PK_LICENSE_ENUM_TPL,
-	PK_LICENSE_ENUM_UCD,
-	PK_LICENSE_ENUM_VIM,
-	PK_LICENSE_ENUM_VNLSL,
-	PK_LICENSE_ENUM_VOSTROM,
-	PK_LICENSE_ENUM_VSL,
-	PK_LICENSE_ENUM_W3C,
-	PK_LICENSE_ENUM_WADALAB,
-	PK_LICENSE_ENUM_WEBMIN,
-	PK_LICENSE_ENUM_WTFPL,
-	PK_LICENSE_ENUM_WXWIDGETS,
-	PK_LICENSE_ENUM_XANO,
-	PK_LICENSE_ENUM_XEROX,
-	PK_LICENSE_ENUM_XINETD,
-	PK_LICENSE_ENUM_XSKAT,
-	PK_LICENSE_ENUM_YPLV1_DOT_1,
-	PK_LICENSE_ENUM_ZEND,
-	PK_LICENSE_ENUM_ZLIB,
-	PK_LICENSE_ENUM_ZLIB_WITH_ACKNOWLEDGEMENT,
-	PK_LICENSE_ENUM_ZPLV1_DOT_0,
-	PK_LICENSE_ENUM_ZPLV2_DOT_0,
-	PK_LICENSE_ENUM_ZPLV2_DOT_1,
-	PK_LICENSE_ENUM_LAST
-} PkLicenseEnum;
-
 /**
  * PkMediaTypeEnum:
  *
@@ -785,9 +558,6 @@ const gchar	*pk_filter_enum_to_string		(PkFilterEnum	 filter);
 PkProvidesEnum	 pk_provides_enum_from_string		(const gchar	*provides);
 const gchar	*pk_provides_enum_to_string		(PkProvidesEnum	 provides);
 
-PkLicenseEnum	 pk_license_enum_from_string		(const gchar	*license);
-const gchar	*pk_license_enum_to_string		(PkLicenseEnum	 license);
-
 PkDistroUpgradeEnum pk_distro_upgrade_enum_from_string	(const gchar	*upgrade);
 const gchar	*pk_distro_upgrade_enum_to_string	(PkDistroUpgradeEnum upgrade);
 
@@ -799,6 +569,10 @@ const gchar	*pk_authorize_type_enum_to_string	(PkAuthorizeEnum authorize_type);
 
 PkUpgradeKindEnum  pk_upgrade_kind_enum_from_string	(const gchar	*upgrade_kind);
 const gchar	*pk_upgrade_kind_enum_to_string		(PkUpgradeKindEnum upgrade_kind);
+const gchar	*pk_status_enum_to_localised_text	(PkStatusEnum	 status);
+const gchar	*pk_info_enum_to_localised_past		(PkInfoEnum	 info);
+const gchar	*pk_info_enum_to_localised_present	(PkInfoEnum	 info);
+const gchar	*pk_role_enum_to_localised_present	(PkRoleEnum	 role);
 
 G_END_DECLS
 
