@@ -108,8 +108,8 @@ pk_task_update_system_sync (PkTask *task, GCancellable *cancellable,
 /**
  * pk_task_remove_packages_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
- * @allow_deps: if other dependant packages are allowed to be removed from the computer
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @allow_deps: if other dependent packages are allowed to be removed from the computer
  * @autoremove: if other packages installed at the same time should be tried to remove
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
@@ -160,7 +160,7 @@ pk_task_remove_packages_sync (PkTask *task, gchar **package_ids, gboolean allow_
 /**
  * pk_task_install_packages_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -208,7 +208,7 @@ pk_task_install_packages_sync (PkTask *task, gchar **package_ids, GCancellable *
 /**
  * pk_task_update_packages_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -256,7 +256,7 @@ pk_task_update_packages_sync (PkTask *task, gchar **package_ids, GCancellable *c
 /**
  * pk_task_install_files_sync:
  * @task: a valid #PkTask instance
- * @files: a file such as "/home/hughsie/Desktop/hal-devel-0.10.0.rpm"
+ * @files: (array zero-terminated=1): a file such as "/home/hughsie/Desktop/hal-devel-0.10.0.rpm"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -351,7 +351,7 @@ pk_task_resolve_sync (PkTask *task, PkBitfield filters, gchar **packages, GCance
  * pk_task_search_names_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -396,7 +396,7 @@ pk_task_search_names_sync (PkTask *task, PkBitfield filters, gchar **values, GCa
  * pk_task_search_details_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -441,7 +441,7 @@ pk_task_search_details_sync (PkTask *task, PkBitfield filters, gchar **values, G
  * pk_task_search_groups_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -486,7 +486,7 @@ pk_task_search_groups_sync (PkTask *task, PkBitfield filters, gchar **values, GC
  * pk_task_search_files_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -530,7 +530,7 @@ pk_task_search_files_sync (PkTask *task, PkBitfield filters, gchar **values, GCa
 /**
  * pk_task_get_details_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -574,7 +574,7 @@ pk_task_get_details_sync (PkTask *task, gchar **package_ids, GCancellable *cance
 /**
  * pk_task_get_update_detail_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -618,7 +618,7 @@ pk_task_get_update_detail_sync (PkTask *task, gchar **package_ids, GCancellable
 /**
  * pk_task_download_packages_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @directory: the destination directory
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
@@ -708,14 +708,14 @@ pk_task_get_updates_sync (PkTask *task, PkBitfield filters, GCancellable *cancel
  * pk_task_get_depends_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @recursive: if we should recurse to packages that depend on other packages
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
  * @error: the #GError to store any failure, or %NULL
  *
- * Get the list of dependant packages.
+ * Get the list of dependent packages.
  *
  * Since: 0.6.5
  **/
@@ -798,7 +798,7 @@ pk_task_get_packages_sync (PkTask *task, PkBitfield filters, GCancellable *cance
  * pk_task_get_requires_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @recursive: if we should return packages that depend on the ones we do
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
@@ -845,7 +845,7 @@ pk_task_get_requires_sync (PkTask *task, PkBitfield filters, gchar **package_ids
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
  * @provides: a #PkProvidesEnum type
- * @values: values to search for
+ * @values: (array zero-terminated=1): values to search for
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -889,7 +889,7 @@ pk_task_what_provides_sync (PkTask *task, PkBitfield filters, PkProvidesEnum pro
 /**
  * pk_task_get_files_sync:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1150,3 +1150,52 @@ pk_task_repo_enable_sync (PkTask *task, const gchar *repo_id, gboolean enabled,
 	return results;
 }
 
+/**
+ * pk_task_repair_system_sync:
+ * @task: a valid #PkTask instance
+ * @cancellable: a #GCancellable or %NULL
+ * @progress_callback: the function to run when the progress changes
+ * @progress_user_data: data to pass to @progress_callback
+ * @error: the #GError to store any failure, or %NULL
+ *
+ * Recover from broken dependencies of installed packages or incomplete
+ * installations.
+ *
+ * Warning: this function is synchronous, and may block. Do not use it in GUI
+ * applications.
+ *
+ * Return value: a %PkResults object, or NULL for error
+ *
+ * Since: 0.7.2
+ **/
+PkResults *
+pk_task_repair_system_sync (PkTask *task, GCancellable *cancellable,
+                            PkProgressCallback progress_callback, gpointer progress_user_data,
+                            GError **error)
+{
+	PkTaskHelper *helper;
+	PkResults *results;
+
+	g_return_val_if_fail (PK_IS_TASK (task), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	/* create temp object */
+	helper = g_new0 (PkTaskHelper, 1);
+	helper->loop = g_main_loop_new (NULL, FALSE);
+	helper->error = error;
+
+	/* run async method */
+	pk_task_repair_system_async (task, cancellable, progress_callback, progress_user_data,
+	                             (GAsyncReadyCallback) pk_task_generic_finish_sync,
+	                             helper);
+
+	g_main_loop_run (helper->loop);
+
+	results = helper->results;
+
+	/* free temp object */
+	g_main_loop_unref (helper->loop);
+	g_free (helper);
+
+	return results;
+}
