@@ -120,6 +120,7 @@ void		pk_backend_initialize			(PkBackend	*backend);
 void		pk_backend_destroy			(PkBackend	*backend);
 void		pk_backend_transaction_start		(PkBackend	*backend);
 void		pk_backend_transaction_stop		(PkBackend	*backend);
+void		pk_backend_transaction_reset		(PkBackend	*backend);
 void		pk_backend_get_categories		(PkBackend	*backend);
 void		pk_backend_get_depends			(PkBackend	*backend,
 							 PkBitfield	 filters,
@@ -203,6 +204,9 @@ void		pk_backend_simulate_update_packages	(PkBackend	*backend,
 void		pk_backend_upgrade_system		(PkBackend	*backend,
 							 const gchar	*distro_id,
 							 PkUpgradeKindEnum upgrade_kind);
+void		pk_backend_repair_system		(PkBackend	*backend,
+							 gboolean	 only_trusted);
+void		pk_backend_simulate_repair_system	(PkBackend	*backend);
 
 /* set the state */
 gboolean	 pk_backend_accept_eula			(PkBackend	*backend,
@@ -481,7 +485,11 @@ typedef struct {
 	void		(*upgrade_system)		(PkBackend	*backend,
 							 const gchar	*distro_id,
 							 PkUpgradeKindEnum upgrade_kind);
-	gpointer	padding[7];
+	void		(*transaction_reset)		(PkBackend	*backend);
+	void		(*repair_system)		(PkBackend	*backend,
+							 gboolean	 only_trusted);
+	void		(*simulate_repair_system)	(PkBackend	*backend);
+	gpointer	padding[4];
 } PkBackendDesc;
 
 G_END_DECLS
