@@ -23,11 +23,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <dbus/dbus-glib.h>
+#include <gio/gio.h>
 #include <NetworkManager.h>
 
-#include "egg-dbus-monitor.h"
-
 #include "pk-network-stack-nm.h"
 #include "pk-conf.h"
 #include "pk-marshal.h"
@@ -38,11 +36,11 @@
 
 struct PkNetworkStackNmPrivate
 {
-	EggDbusMonitor		*dbus_monitor;
+	guint			 watch_id;
 	PkConf			*conf;
-	DBusGConnection		*bus;
+	GDBusConnection		*bus;
 	gboolean		 is_enabled;
-	DBusGProxy		*proxy_changed;
+	GDBusProxy		*proxy_changed;
 };
 
 G_DEFINE_TYPE (PkNetworkStackNm, pk_network_stack_nm, PK_TYPE_NETWORK_STACK)
@@ -55,7 +53,8 @@ G_DEFINE_TYPE (PkNetworkStackNm, pk_network_stack_nm, PK_TYPE_NETWORK_STACK)
  * important connection even bridged we should prioritise it
  **/
 static NMDeviceType
-pk_network_stack_nm_prioritise_connection_type (NMDeviceType type_old, NMDeviceType type_new)
+pk_network_stack_nm_prioritise_connection_type (NMDeviceType type_old,
+						NMDeviceType type_new)
 {
 	NMDeviceType type = type_old;
 	/* by sheer fluke we can use the enum ordering */
@@ -68,32 +67,36 @@ pk_network_stack_nm_prioritise_connection_type (NMDeviceType type_old, NMDeviceT
  * pk_network_stack_nm_get_active_connection_type_for_device:
  **/
 static NMDeviceType
-pk_network_stack_nm_get_active_connection_type_for_device (PkNetworkStackNm *nstack_nm, const gchar *device)
+pk_network_stack_nm_get_active_connection_type_for_device (PkNetworkStackNm *nstack_nm,
+							   const gchar *device)
 {
-	gboolean ret;
+	GDBusProxy *proxy;
 	GError *error = NULL;
-	DBusGProxy *proxy;
-	GValue value = { 0 };
+	GVariant *value = NULL;
 	NMDeviceType type = NM_DEVICE_TYPE_UNKNOWN;
 
 	/* get if the device is default */
-	proxy = dbus_g_proxy_new_for_name (nstack_nm->priv->bus, "org.freedesktop.NetworkManager",
-					   device, "org.freedesktop.DBus.Properties");
-	ret = dbus_g_proxy_call (proxy, "Get", &error,
-				 G_TYPE_STRING, "org.freedesktop.NetworkManager.Device",
-				 G_TYPE_STRING, "DeviceType",
-				 G_TYPE_INVALID,
-				 G_TYPE_VALUE, &value,
-				 G_TYPE_INVALID);
-	if (!ret) {
+	proxy = g_dbus_proxy_new_sync (nstack_nm->priv->bus,
+				       G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+				       NULL,
+				       "org.freedesktop.NetworkManager",
+				       device,
+				       "org.freedesktop.NetworkManager.Device",
+				       NULL,
+				       &error);
+	if (proxy == NULL) {
 		g_warning ("Error getting DeviceType: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
-	type = g_value_get_uint (&value);
+	value = g_dbus_proxy_get_cached_property (proxy, "DeviceType");
+	type = g_variant_get_uint32 (value);
 	g_debug ("type: %i", type);
 out:
-	g_object_unref (proxy);
+	if (proxy != NULL)
+		g_object_unref (proxy);
+	if (value != NULL)
+		g_variant_unref (value);
 	return type;
 }
 
@@ -101,35 +104,35 @@ out:
  * pk_network_stack_nm_get_active_connection_type_for_connection:
  **/
 static NMDeviceType
-pk_network_stack_nm_get_active_connection_type_for_connection (PkNetworkStackNm *nstack_nm, const gchar *active_connection)
+pk_network_stack_nm_get_active_connection_type_for_connection (PkNetworkStackNm *nstack_nm,
+							       const gchar *active_connection)
 {
-	guint i;
-	gboolean ret;
-	GError *error = NULL;
-	DBusGProxy *proxy;
 	const gchar *device;
-	GValue value_default = { 0 };
-	GValue value_devices = { 0 };
 	gboolean is_default;
-	GPtrArray *devices;
-	NMDeviceType type_tmp;
+	GDBusProxy *proxy;
+	GError *error = NULL;
+	GVariantIter *iter = NULL;
+	GVariant *value_default = NULL;
+	GVariant *value_devices = NULL;
 	NMDeviceType type = NM_DEVICE_TYPE_UNKNOWN;
+	NMDeviceType type_tmp;
 
 	/* get if the device is default */
-	proxy = dbus_g_proxy_new_for_name (nstack_nm->priv->bus, "org.freedesktop.NetworkManager",
-					   active_connection, "org.freedesktop.DBus.Properties");
-	ret = dbus_g_proxy_call (proxy, "Get", &error,
-				 G_TYPE_STRING, "org.freedesktop.NetworkManager.Connection.Active",
-				 G_TYPE_STRING, "Default",
-				 G_TYPE_INVALID,
-				 G_TYPE_VALUE, &value_default,
-				 G_TYPE_INVALID);
-	if (!ret) {
+	proxy = g_dbus_proxy_new_sync (nstack_nm->priv->bus,
+				       G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+				       NULL,
+				       "org.freedesktop.NetworkManager",
+				       active_connection,
+				       "org.freedesktop.NetworkManager.Connection.Active",
+				       NULL,
+				       &error);
+	if (proxy == NULL) {
 		g_warning ("Error getting Default: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
-	is_default = g_value_get_boolean (&value_default);
+	value_default = g_dbus_proxy_get_cached_property (proxy, "Default");
+	is_default = g_variant_get_boolean (value_default);
 	g_debug ("is_default: %i", is_default);
 	if (!is_default) {
 		g_debug ("not default, skipping");
@@ -137,32 +140,25 @@ pk_network_stack_nm_get_active_connection_type_for_connection (PkNetworkStackNm
 	}
 
 	/* get the physical devices for the connection */
-	ret = dbus_g_proxy_call (proxy, "Get", &error,
-				 G_TYPE_STRING, "org.freedesktop.NetworkManager.Connection.Active",
-				 G_TYPE_STRING, "Devices",
-				 G_TYPE_INVALID,
-				 G_TYPE_VALUE, &value_devices,
-				 G_TYPE_INVALID);
-	if (!ret) {
-		g_warning ("Error getting Devices: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	devices = g_value_get_boxed (&value_devices);
-	g_debug ("number of devices: %i", devices->len);
-	if (devices->len == 0)
-		goto out;
+	value_devices = g_dbus_proxy_get_cached_property (proxy, "Devices");
+	g_variant_get (value_devices, "ao", &iter);
 
 	/* find the types of the active connection */
-	for (i=0; i<devices->len; i++) {
-		device = g_ptr_array_index (devices, i);
-		type_tmp = pk_network_stack_nm_get_active_connection_type_for_device (nstack_nm, device);
-		type = pk_network_stack_nm_prioritise_connection_type (type, type_tmp);
+	while (g_variant_iter_next (iter, "&o", &device)) {
+		type_tmp = pk_network_stack_nm_get_active_connection_type_for_device (nstack_nm,
+										      device);
+		type = pk_network_stack_nm_prioritise_connection_type (type,
+								       type_tmp);
 	}
-
 out:
-	g_object_unref (proxy);
+	if (iter != NULL)
+		g_variant_iter_free (iter);
+	if (proxy != NULL)
+		g_object_unref (proxy);
+	if (value_devices != NULL)
+		g_variant_unref (value_devices);
+	if (value_default != NULL)
+		g_variant_unref (value_default);
 	return type;
 }
 
@@ -172,48 +168,45 @@ out:
 static NMDeviceType
 pk_network_stack_nm_get_active_connection_type (PkNetworkStackNm *nstack_nm)
 {
-	guint i;
-	gboolean ret;
-	DBusGProxy *proxy;
-	GError *error = NULL;
-	GPtrArray *active_connections = NULL;
 	const gchar *active_connection;
-	GValue value = { 0 };
-	NMDeviceType type_tmp;
+	GDBusProxy *proxy;
+	GError *error = NULL;
+	GVariantIter *iter = NULL;
+	GVariant *value = NULL;
 	NMDeviceType type = NM_DEVICE_TYPE_UNKNOWN;
+	NMDeviceType type_tmp;
 
 	/* get proxy */
-	proxy = dbus_g_proxy_new_for_name (nstack_nm->priv->bus, "org.freedesktop.NetworkManager",
-					   "/org/freedesktop/NetworkManager",
-					   "org.freedesktop.DBus.Properties");
-	ret = dbus_g_proxy_call (proxy, "Get", &error,
-				 G_TYPE_STRING, "org.freedesktop.NetworkManager",
-				 G_TYPE_STRING, "ActiveConnections",
-				 G_TYPE_INVALID,
-				 G_TYPE_VALUE, &value,
-				 G_TYPE_INVALID);
-	if (!ret) {
+	proxy = g_dbus_proxy_new_sync (nstack_nm->priv->bus,
+				       G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+				       NULL,
+				       "org.freedesktop.NetworkManager",
+				       "/org/freedesktop/NetworkManager",
+				       "org.freedesktop.NetworkManager",
+				       NULL,
+				       &error);
+	if (proxy == NULL) {
 		g_warning ("Error getting ActiveConnections: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
-
-	active_connections = g_value_get_boxed (&value);
-	g_debug ("active connections: %i", active_connections->len);
-	if (active_connections->len == 0)
-		goto out;
+	value = g_dbus_proxy_get_cached_property (proxy, "ActiveConnections");
+	g_variant_get (value, "ao", &iter);
 
 	/* find the active connection */
-	for (i=0; i<active_connections->len; i++) {
-		active_connection = g_ptr_array_index (active_connections, i);
-		type_tmp = pk_network_stack_nm_get_active_connection_type_for_connection (nstack_nm, active_connection);
+	while (g_variant_iter_next (iter, "&o", &active_connection)) {
+		type_tmp = pk_network_stack_nm_get_active_connection_type_for_connection (nstack_nm,
+											  active_connection);
 		type = pk_network_stack_nm_prioritise_connection_type (type, type_tmp);
 	}
 
 out:
-	g_object_unref (proxy);
-	g_ptr_array_foreach (active_connections, (GFunc) g_free, NULL);
-	g_ptr_array_free (active_connections, TRUE);
+	if (iter != NULL)
+		g_variant_iter_free (iter);
+	if (proxy != NULL)
+		g_object_unref (proxy);
+	if (value != NULL)
+		g_variant_unref (value);
 	return type;
 }
 
@@ -258,27 +251,6 @@ pk_network_stack_nm_get_state (PkNetworkStack *nstack)
 	return ret;
 }
 
-/**
- * pk_network_stack_nm_status_changed_cb:
- */
-static void
-pk_network_stack_nm_status_changed_cb (DBusGProxy *proxy, guint status, PkNetworkStackNm *nstack_nm)
-{
-	PkNetworkEnum state;
-
-	g_return_if_fail (PK_IS_NETWORK_STACK_NM (nstack_nm));
-
-	/* do not use */
-	if (!nstack_nm->priv->is_enabled) {
-		g_debug ("not enabled, so ignoring");
-		return;
-	}
-
-	state = pk_network_stack_nm_get_state (PK_NETWORK_STACK (nstack_nm));
-	g_debug ("emitting network-state-changed: %s", pk_network_enum_to_string (state));
-	g_signal_emit_by_name (PK_NETWORK_STACK (nstack_nm), "state-changed", state);
-}
-
 /**
  * pk_network_stack_nm_is_enabled:
  *
@@ -291,6 +263,62 @@ pk_network_stack_nm_is_enabled (PkNetworkStack *nstack)
 	return nstack_nm->priv->is_enabled;
 }
 
+/**
+ * pk_network_stack_nm_appeared_cb:
+ **/
+static void
+pk_network_stack_nm_appeared_cb (GDBusConnection *connection,
+				 const gchar *name,
+				 const gchar *name_owner,
+				 gpointer user_data)
+{
+	gboolean ret;
+	PkNetworkStackNm *nstack_nm = PK_NETWORK_STACK_NM (user_data);
+	ret = pk_conf_get_bool (nstack_nm->priv->conf,
+				"UseNetworkManager");
+	nstack_nm->priv->is_enabled = ret;
+}
+
+/**
+ * pk_network_stack_nm_vanished_cb:
+ **/
+static void
+pk_network_stack_nm_vanished_cb (GDBusConnection *connection,
+				 const gchar *name,
+				 gpointer user_data)
+{
+	PkNetworkStackNm *nstack_nm = PK_NETWORK_STACK_NM (user_data);
+	nstack_nm->priv->is_enabled = FALSE;
+}
+
+/**
+ * pk_network_stack_nm_dbus_signal_cb:
+ **/
+static void
+pk_network_stack_nm_dbus_signal_cb (GDBusProxy *proxy,
+				    gchar *sender_name,
+				    gchar *signal_name,
+				    GVariant *parameters,
+				    PkNetworkStackNm *nstack_nm)
+{
+	PkNetworkEnum state;
+
+	g_return_if_fail (PK_IS_NETWORK_STACK_NM (nstack_nm));
+
+	/* do not use */
+	if (!nstack_nm->priv->is_enabled) {
+		g_debug ("not enabled, so ignoring %s", signal_name);
+		return;
+	}
+
+	/* don't use parameters, just refresh state */
+	if (g_strcmp0 (signal_name, "StateChanged") == 0) {
+		state = pk_network_stack_nm_get_state (PK_NETWORK_STACK (nstack_nm));
+		g_debug ("emitting network-state-changed: %s", pk_network_enum_to_string (state));
+		g_signal_emit_by_name (PK_NETWORK_STACK (nstack_nm), "state-changed", state);
+	}
+}
+
 /**
  * pk_network_stack_nm_init:
  **/
@@ -298,40 +326,41 @@ static void
 pk_network_stack_nm_init (PkNetworkStackNm *nstack_nm)
 {
 	GError *error = NULL;
-	gboolean service_alive;
 
 	nstack_nm->priv = PK_NETWORK_STACK_NM_GET_PRIVATE (nstack_nm);
 	nstack_nm->priv->conf = pk_conf_new ();
 
-	/* do we use this code? */
-	nstack_nm->priv->is_enabled = pk_conf_get_bool (nstack_nm->priv->conf, "UseNetworkManager");
-
 	/* get system connection */
-	nstack_nm->priv->bus = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
+	nstack_nm->priv->bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
 	if (nstack_nm->priv->bus == NULL) {
 		g_warning ("Couldn't connect to system bus: %s", error->message);
 		g_error_free (error);
 	}
 
 	/* check if NM is on the bus */
-	nstack_nm->priv->dbus_monitor = egg_dbus_monitor_new ();
-	egg_dbus_monitor_assign (nstack_nm->priv->dbus_monitor, EGG_DBUS_MONITOR_SYSTEM, "org.freedesktop.NetworkManager");
-	service_alive = egg_dbus_monitor_is_connected (nstack_nm->priv->dbus_monitor);
+	nstack_nm->priv->watch_id =
+		g_bus_watch_name (G_BUS_TYPE_SYSTEM,
+				  "org.freedesktop.NetworkManager",
+				  G_BUS_NAME_WATCHER_FLAGS_NONE,
+				  pk_network_stack_nm_appeared_cb,
+				  pk_network_stack_nm_vanished_cb,
+				  nstack_nm,
+				  NULL);
 
-	/* connect to changed as libnm-glib is teh suck and causes multithreading issues with dbus-glib */
-	nstack_nm->priv->proxy_changed = dbus_g_proxy_new_for_name (nstack_nm->priv->bus,
-								    "org.freedesktop.NetworkManager",
-								    "/org/freedesktop/NetworkManager",
-								    "org.freedesktop.NetworkManager");
-	dbus_g_proxy_add_signal (nstack_nm->priv->proxy_changed, "StateChanged", G_TYPE_UINT, G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (nstack_nm->priv->proxy_changed, "StateChanged",
-				     G_CALLBACK (pk_network_stack_nm_status_changed_cb), nstack_nm, NULL);
-
-	/* NetworkManager isn't up, so we can't use it */
-	if (nstack_nm->priv->is_enabled && !service_alive) {
-		g_warning ("UseNetworkManager true, but org.freedesktop.NetworkManager not up");
-		nstack_nm->priv->is_enabled = FALSE;
-	}
+	/* connect to changed as libnm-glib is teh suc */
+	nstack_nm->priv->proxy_changed =
+		g_dbus_proxy_new_sync (nstack_nm->priv->bus,
+				       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+				       NULL,
+				       "org.freedesktop.NetworkManager",
+				       "/org/freedesktop/NetworkManager",
+				       "org.freedesktop.NetworkManager",
+				       NULL,
+				       &error);
+	g_signal_connect (nstack_nm->priv->proxy_changed,
+			  "g-signal",
+			  G_CALLBACK (pk_network_stack_nm_dbus_signal_cb),
+			  nstack_nm);
 }
 
 /**
@@ -346,13 +375,10 @@ pk_network_stack_nm_finalize (GObject *object)
 	g_return_if_fail (PK_IS_NETWORK_STACK_NM (object));
 
 	nstack_nm = PK_NETWORK_STACK_NM (object);
-	g_return_if_fail (nstack_nm->priv != NULL);
 
-	dbus_g_proxy_disconnect_signal (nstack_nm->priv->proxy_changed, "StateChanged",
-					G_CALLBACK (pk_network_stack_nm_status_changed_cb), nstack_nm);
 	g_object_unref (nstack_nm->priv->proxy_changed);
 	g_object_unref (nstack_nm->priv->conf);
-	g_object_unref (nstack_nm->priv->dbus_monitor);
+	g_bus_unwatch_name (nstack_nm->priv->watch_id);
 
 	G_OBJECT_CLASS (pk_network_stack_nm_parent_class)->finalize (object);
 }
