@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007-2010 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2011 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -31,20 +31,18 @@
 #include "pk-conf.h"
 #include "pk-dbus.h"
 #include "pk-engine.h"
-#include "pk-file-monitor.h"
-#include "pk-inhibit.h"
-#include "pk-lsof.h"
 #include "pk-notify.h"
-#include "pk-proc.h"
-#include "pk-syslog.h"
 #include "pk-spawn.h"
+#include "pk-store.h"
+#include "pk-syslog.h"
 #include "pk-time.h"
 #include "pk-transaction-db.h"
-#include "pk-transaction-db.h"
-#include "pk-transaction-extra.h"
 #include "pk-transaction.h"
+#include "pk-transaction-private.h"
 #include "pk-transaction-list.h"
 
+#define PK_TRANSACTION_ERROR_INPUT_INVALID	14
+
 /** ver:1.0 ***********************************************************/
 static GMainLoop *_test_loop = NULL;
 static guint _test_loop_timeout_id = 0;
@@ -659,231 +657,6 @@ pk_test_engine_emit_repo_list_changed_cb (void)
 	return FALSE;
 }
 
-static void
-pk_test_engine_func (void)
-{
-	gboolean ret;
-	PkEngine *engine;
-	PkBackend *backend;
-	PkInhibit *inhibit;
-	guint idle;
-	gchar *state;
-	gdouble elapsed;
-
-	backend = pk_backend_new ();
-	g_assert (backend != NULL);
-
-	notify = pk_notify_new ();
-	g_assert (notify != NULL);
-
-	/* set the type, as we have no pk-main doing this for us */
-	/* set the backend name */
-	ret = pk_backend_set_name (backend, "dummy", NULL);
-	g_assert (ret);
-
-	/* get an engine instance */
-	engine = pk_engine_new ();
-	g_assert (engine != NULL);
-
-	/* connect up signals */
-	g_signal_connect (engine, "quit",
-			  G_CALLBACK (pk_test_engine_quit_cb), NULL);
-	g_signal_connect (engine, "changed",
-			  G_CALLBACK (pk_test_engine_changed_cb), NULL);
-	g_signal_connect (engine, "updates-changed",
-			  G_CALLBACK (pk_test_engine_updates_changed_cb), NULL);
-	g_signal_connect (engine, "repo-list-changed",
-			  G_CALLBACK (pk_test_engine_repo_list_changed_cb), NULL);
-	g_signal_connect (engine, "restart-schedule",
-			  G_CALLBACK (pk_test_engine_restart_schedule_cb), NULL);
-
-	/* get idle at startup */
-	idle = pk_engine_get_seconds_idle (engine);
-	g_assert_cmpint (idle, <, 1);
-
-	/* wait 5 seconds */
-	_g_test_loop_wait (5000);
-
-	/* get idle at idle */
-	idle = pk_engine_get_seconds_idle (engine);
-	g_assert_cmpint (idle, <, 6);
-	g_assert_cmpint (idle, >, 4);
-
-	/* get idle after method */
-	pk_engine_get_daemon_state (engine, &state, NULL);
-	g_free (state);
-	idle = pk_engine_get_seconds_idle (engine);
-	g_assert_cmpint (idle, <, 1);
-
-	/* force test notify updates-changed */
-	g_timeout_add (25, (GSourceFunc) pk_test_engine_emit_updates_changed_cb, NULL);
-	_g_test_loop_wait (50);
-
-	/* force test notify repo-list-changed */
-	g_timeout_add (25, (GSourceFunc) pk_test_engine_emit_repo_list_changed_cb, NULL);
-	_g_test_loop_wait (50);
-
-	/* force test notify wait updates-changed */
-	g_test_timer_start ();
-	pk_notify_wait_updates_changed (notify, 500);
-	_g_test_loop_run_with_timeout (1500);
-	elapsed = g_test_timer_elapsed ();
-	g_assert_cmpfloat (elapsed, >, 0.4);
-	g_assert_cmpfloat (elapsed, <, 0.6);
-
-	/* test locked */
-	inhibit = pk_inhibit_new ();
-	pk_inhibit_add (inhibit, GUINT_TO_POINTER (999));
-	g_assert (_locked);
-
-	/* test locked */
-	pk_inhibit_remove (inhibit, GUINT_TO_POINTER (999));
-	g_assert (!_locked);
-	g_object_unref (inhibit);
-
-	/* test not locked */
-	g_assert (!_locked);
-	g_assert (!_restart_schedule);
-
-	ret = g_file_set_contents (SBINDIR "/packagekitd", "overwrite", -1, NULL);
-	g_assert (ret);
-	_g_test_loop_wait (5000);
-
-	/* get idle after we touched the binary */
-	idle = pk_engine_get_seconds_idle (engine);
-	g_assert_cmpint (idle, ==, G_MAXUINT);
-	g_assert (_restart_schedule);
-	g_assert (!_quit);
-
-	/* suggest quit with no transactions (should get quit signal) */
-	pk_engine_suggest_daemon_quit (engine, NULL);
-	g_assert (_quit);
-
-	g_object_unref (backend);
-	g_object_unref (notify);
-	g_object_unref (engine);
-}
-
-static void
-pk_test_file_monitor_func (void)
-{
-	PkFileMonitor *file_monitor;
-
-	/* get a file_monitor */
-	file_monitor = pk_file_monitor_new ();
-	g_assert (file_monitor != NULL);
-	g_object_unref (file_monitor);
-}
-
-static void
-pk_test_inhibit_func (void)
-{
-	PkInhibit *inhibit;
-	gboolean ret;
-
-	inhibit = pk_inhibit_new ();
-	g_assert (inhibit != NULL);
-
-	/* check we are not inhibited */
-	ret = pk_inhibit_locked (inhibit);
-	g_assert (!ret);
-
-	/* add 123 */
-	ret = pk_inhibit_add (inhibit, GUINT_TO_POINTER (123));
-	g_assert (ret);
-
-	/* check we are inhibited */
-	ret = pk_inhibit_locked (inhibit);
-	g_assert (ret);
-
-	/* add 123 (again) */
-	ret = pk_inhibit_add (inhibit, GUINT_TO_POINTER (123));
-	g_assert (!ret);
-
-	/* add 456 */
-	ret = pk_inhibit_add (inhibit, GUINT_TO_POINTER (456));
-	g_assert (ret);
-
-	/* remove 123" */
-	ret = pk_inhibit_remove (inhibit, GUINT_TO_POINTER (123));
-	g_assert (ret);
-
-	/* check we are still inhibited */
-	ret = pk_inhibit_locked (inhibit);
-	g_assert (ret);
-
-	/* remove 456 */
-	ret = pk_inhibit_remove (inhibit, GUINT_TO_POINTER (456));
-	g_assert (ret);
-
-	/* check we are not inhibited */
-	ret = pk_inhibit_locked (inhibit);
-	g_assert (!ret);
-
-	g_object_unref (inhibit);
-}
-
-static void
-pk_test_lsof_get_files_for_directory (GPtrArray *files, const gchar *dirname)
-{
-	GDir *dir;
-	const gchar *filename;
-	dir = g_dir_open (dirname, 0, NULL);
-	if (dir == NULL)
-		return;
-	filename = g_dir_read_name (dir);
-	while (filename != NULL) {
-		if (g_str_has_prefix (filename, "libglib-2.0.so"))
-			g_ptr_array_add (files,
-					 g_build_filename (dirname, filename, NULL));
-		filename = g_dir_read_name (dir);
-	}
-	g_dir_close (dir);
-}
-
-static gchar **
-pk_test_lsof_get_files (void)
-{
-	GPtrArray *files;
-	gchar **retval;
-
-	files = g_ptr_array_new_with_free_func (g_free);
-	pk_test_lsof_get_files_for_directory (files, "/lib");
-	pk_test_lsof_get_files_for_directory (files, "/usr/lib");
-	pk_test_lsof_get_files_for_directory (files, "/usr/lib64");
-
-	/* convert to gchar ** */
-	retval = pk_ptr_array_to_strv (files);
-	g_ptr_array_unref (files);
-	return retval;
-}
-
-static void
-pk_test_lsof_func (void)
-{
-	gboolean ret;
-	PkLsof *lsof;
-	GPtrArray *pids;
-	gchar **files;
-
-	lsof = pk_lsof_new ();
-	g_assert (lsof != NULL);
-
-	/* refresh lsof data */
-	ret = pk_lsof_refresh (lsof);
-	g_assert (ret);
-
-	/* get pids for some test files */
-	files = pk_test_lsof_get_files ();
-	g_assert_cmpint (g_strv_length (files), >, 0);
-	pids = pk_lsof_get_pids_for_filenames (lsof, files);
-	g_assert_cmpint (pids->len, >, 0);
-	g_ptr_array_unref (pids);
-
-	g_strfreev (files);
-	g_object_unref (lsof);
-}
-
 static void
 pk_test_notify_func (void)
 {
@@ -895,23 +668,6 @@ pk_test_notify_func (void)
 	g_object_unref (notify);
 }
 
-static void
-pk_test_proc_func (void)
-{
-	gboolean ret;
-	PkProc *proc;
-//	gchar *files[] = { "/sbin/udevd", NULL };
-
-	proc = pk_proc_new ();
-	g_assert (proc != NULL);
-
-	/* refresh proc data */
-	ret = pk_proc_refresh (proc);
-	g_assert (ret);
-
-	g_object_unref (proc);
-}
-
 PkSpawnExitType mexit = PK_SPAWN_EXIT_TYPE_UNKNOWN;
 guint stdout_count = 0;
 guint finished_count = 0;
@@ -1296,6 +1052,16 @@ pk_test_transaction_func (void)
 	PkTransaction *transaction = NULL;
 	gboolean ret;
 	GError *error = NULL;
+	PkBackend *backend;
+
+	backend = pk_backend_new ();
+	/* try to load a valid backend */
+	ret = pk_backend_set_name (backend, "dummy", NULL);
+	g_assert (ret);
+
+	/* lock an valid backend */
+	ret = pk_backend_lock (backend);
+	g_assert (ret);
 
 	/* get PkTransaction object */
 	transaction = pk_transaction_new ();
@@ -1375,6 +1141,7 @@ pk_test_transaction_func (void)
 	g_clear_error (&error);
 
 	g_object_unref (transaction);
+	g_object_unref (backend);
 }
 
 static void
@@ -1529,17 +1296,6 @@ pk_test_transaction_db_func (void)
 	g_object_unref (db);
 }
 
-static void
-pk_test_transaction_extra_func (void)
-{
-	PkTransactionExtra *extra;
-
-	extra = pk_transaction_extra_new ();
-	g_assert (extra != NULL);
-
-	g_object_unref (extra);
-}
-
 static PkTransactionDb *db = NULL;
 
 /**
@@ -1598,6 +1354,15 @@ pk_test_transaction_list_func (void)
 	cache = pk_cache_new ();
 	db = pk_transaction_db_new ();
 
+	/* try to load a valid backend */
+	backend = pk_backend_new ();
+	ret = pk_backend_set_name (backend, "dummy", NULL);
+	g_assert (ret);
+
+	/* lock an valid backend */
+	ret = pk_backend_lock (backend);
+	g_assert (ret);
+
 	/* get a transaction list object */
 	tlist = pk_transaction_list_new ();
 	g_assert (tlist != NULL);
@@ -1645,15 +1410,6 @@ pk_test_transaction_list_func (void)
 	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
 	g_assert (ret);
 
-	backend = pk_backend_new ();
-	/* try to load a valid backend */
-	ret = pk_backend_set_name (backend, "dummy", NULL);
-	g_assert (ret);
-
-	/* lock an valid backend */
-	ret = pk_backend_lock (backend);
-	g_assert (ret);
-
 	/* get from db */
 	transaction = pk_transaction_list_get_transaction (tlist, tid);
 	g_assert (transaction != NULL);
@@ -1661,7 +1417,7 @@ pk_test_transaction_list_func (void)
 			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
 
 	/* this tests the run-on-commit action */
-	pk_transaction_get_updates (transaction, "none", NULL);
+	pk_transaction_get_updates (transaction, g_variant_new ("(s)", "none"), NULL);
 
 	/* make sure transaction has correct flags */
 	transaction = pk_transaction_list_get_transaction (tlist, tid);
@@ -1739,19 +1495,25 @@ pk_test_transaction_list_func (void)
 	/* this starts one action */
 	array = g_strsplit ("dave", " ", -1);
 	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
-	pk_transaction_search_details (transaction, "none", array, NULL);
+	pk_transaction_search_details (transaction,
+				       g_variant_new ("(s^as)", "none", array),
+				       NULL);
 	g_strfreev (array);
 
 	/* this should be chained after the first action completes */
 	array = g_strsplit ("power", " ", -1);
 	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
-	pk_transaction_search_names (transaction, "none", array, NULL);
+	pk_transaction_search_names (transaction,
+				     g_variant_new ("(s^as)", "none", array),
+				     NULL);
 	g_strfreev (array);
 
 	/* this starts be chained after the second action completes */
 	array = g_strsplit ("paul", " ", -1);
 	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
-	pk_transaction_search_details (transaction, "none", array, NULL);
+	pk_transaction_search_details (transaction,
+				       g_variant_new ("(s^as)", "none", array),
+				       NULL);
 	g_strfreev (array);
 
 	/* get transactions (committed, not finished) in progress (all) */
@@ -1857,8 +1619,6 @@ pk_test_transaction_list_func (void)
 int
 main (int argc, char **argv)
 {
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
 	g_type_init ();
 	g_test_init (&argc, &argv, NULL);
 
@@ -1867,30 +1627,21 @@ main (int argc, char **argv)
 #endif
 
 	/* components */
-	g_test_add_func ("/packagekit/notify", pk_test_proc_func);
-	g_test_add_func ("/packagekit/proc", pk_test_proc_func);
-	g_test_add_func ("/packagekit/lsof", pk_test_lsof_func);
-	g_test_add_func ("/packagekit/file-monitor", pk_test_file_monitor_func);
 	g_test_add_func ("/packagekit/time", pk_test_time_func);
 	g_test_add_func ("/packagekit/dbus", pk_test_dbus_func);
 	g_test_add_func ("/packagekit/syslog", pk_test_dbus_func);
 	g_test_add_func ("/packagekit/conf", pk_test_conf_func);
 	g_test_add_func ("/packagekit/cache", pk_test_conf_func);
 	g_test_add_func ("/packagekit/store", pk_test_store_func);
-	g_test_add_func ("/packagekit/inhibit", pk_test_inhibit_func);
 	g_test_add_func ("/packagekit/spawn", pk_test_spawn_func);
 	g_test_add_func ("/packagekit/transaction", pk_test_transaction_func);
 	g_test_add_func ("/packagekit/transaction-list", pk_test_transaction_list_func);
 	g_test_add_func ("/packagekit/transaction-db", pk_test_transaction_db_func);
-	g_test_add_func ("/packagekit/transaction-extra", pk_test_transaction_extra_func);
 
 	/* backend stuff */
 	g_test_add_func ("/packagekit/backend", pk_test_backend_func);
 	g_test_add_func ("/packagekit/backend_spawn", pk_test_backend_spawn_func);
 
-	/* system */
-	g_test_add_func ("/packagekit/engine", pk_test_engine_func);
-
 	return g_test_run ();
 }
 
