@@ -23,6 +23,7 @@
 #define __PK_SHARED_H
 
 #include <glib.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
@@ -37,7 +38,21 @@ typedef enum {
 
 gboolean	 pk_directory_remove_contents		(const gchar	*directory);
 const gchar	*pk_hint_enum_to_string			(PkHintEnum	 hint);
-PkHintEnum	 pk_hint_enum_from_string			(const gchar	*hint);
+PkHintEnum	 pk_hint_enum_from_string		(const gchar	*hint);
+
+guint		 pk_strlen				(const gchar	*text,
+							 guint		 len)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_strzero				(const gchar	*text)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_strtoint				(const gchar	*text,
+							 gint		*value);
+gboolean	 pk_strtouint				(const gchar	*text,
+							 guint		*value);
+gboolean	 pk_strtouint64				(const gchar	*text,
+							 guint64	*value);
+GDBusNodeInfo	*pk_load_introspection			(const gchar	*filename,
+							 GError		**error);
 
 G_END_DECLS
 
